@@ -2,6 +2,7 @@ import os
 import traceback
 from .debug_config import DebugConfig
 from .asker import Asker
+from .const import Const
 
 
 class DrillDown:
@@ -16,14 +17,16 @@ class DrillDown:
         #
         # get name
         #
+        t = self._get_add_type()
+        if t == Const.CANCEL2:
+            return
         self._cli.clear()
-        name = Asker(self._cli, name_type="files").ask()
+        name = None
+        if t == "file":
+            name = Asker(self._cli, name_type="files").ask()
         #
         # get path
         #
-        t = self._get_add_type()
-        if t == self._cli.CANCEL2:
-            return
         p = self._get_path(t, self._cli.csvpaths.config.csv_file_extensions)
         if p is False:
             return
@@ -63,17 +66,19 @@ class DrillDown:
     # ============================
 
     def name_paths(self):
+        t = self._get_add_type()
+        if t == Const.CANCEL2:
+            return
         #
         # get name
         #
         self._cli.clear()
-        name = Asker(self._cli, name_type="files").ask()
+        name = None
+        if t == "file":
+            name = Asker(self._cli, name_type="paths").ask()
         #
         # get path
         #
-        t = self._get_add_type()
-        if t == self._cli.CANCEL2:
-            return
         exts = self._cli.csvpaths.config.csvpath_file_extensions
         p = self._get_path(t, exts)
         if p is False:
@@ -95,7 +100,8 @@ class DrillDown:
                 )
             else:
                 self._cli.csvpaths.paths_manager.add_named_paths_from_json(file_path=p)
-        except Exception:
+        except Exception as e:
+            self._cli.csvpaths.logger.error(e)
             cfg = None
             while cfg in [None, "c", "e"]:
                 print("\nThere was an error.")
@@ -144,7 +150,7 @@ class DrillDown:
 
     def _get_add_type(self) -> str:
         self._cli.clear()
-        choices = ["dir", "file", "json", self._cli.CANCEL2]
+        choices = ["dir", "file", "json", Const.CANCEL2]
         t = None
         t = self._cli.ask(choices)
         return t
@@ -159,9 +165,9 @@ class DrillDown:
         names.sort()
         names = self._decorate(path, names, select_dir=dir_only)
         t = self._cli.ask(names)
-        if t in [self._cli.STOP_HERE, self._cli.STOP_HERE2]:
+        if t in [Const.STOP_HERE, Const.STOP_HERE2]:
             return (path, True)
-        if t in [self._cli.CANCEL, self._cli.CANCEL2]:
+        if t in [Const.CANCEL, Const.CANCEL2]:
             return (path, False)
         if t.startswith("📂 ") or t.startswith("📄 "):
             t = t[2:]
@@ -170,7 +176,7 @@ class DrillDown:
     def _decorate(self, path, names, select_dir=False) -> list[str]:
         ns = []
         for n in names:
-            if n in [self._cli.STOP_HERE, self._cli.STOP_HERE2]:
+            if n in [Const.STOP_HERE, Const.STOP_HERE2]:
                 pass
             elif os.path.isfile(os.path.join(path, n)):
                 n = f"📄 {n}"
@@ -178,8 +184,8 @@ class DrillDown:
                 n = f"📂 {n}"
             ns.append(n)
         if select_dir is True:
-            ns.append(self._cli.STOP_HERE)
-        ns.append(self._cli.CANCEL)
+            ns.append(Const.STOP_HERE)
+        ns.append(Const.CANCEL)
         return ns
 
     def _filter_hidden(self, names) -> list[str]:
