@@ -2,6 +2,8 @@ from csvpath.managers.metadata import Metadata
 
 
 class FileMetadata(Metadata):
+    """@private"""
+
     def __init__(self, config):
         super().__init__(config)
         # like aname
@@ -20,3 +22,5 @@ class FileMetadata(Metadata):
         self.mark = None
         # like csv
         self.type = None
+        self.file_size = 0
+        self.template = None
