@@ -2,16 +2,16 @@ import os
 import json
 from datetime import datetime
 from csvpath.util.exceptions import InputException, FileException
-from csvpath.util.file_readers import DataFileReader
-from csvpath.util.file_writers import DataFileWriter
 from csvpath.util.nos import Nos
 from csvpath.managers.registrar import Registrar
 from csvpath.managers.listener import Listener
 from csvpath.managers.metadata import Metadata
+from csvpath.util.intermediary import Intermediary
 
 
 class FileRegistrar(Registrar, Listener):
-    """this file registers the metadata with a tracking system. e.g. an OpenLineage
+    """@private
+    this file registers the metadata with a tracking system. e.g. an OpenLineage
     server, JSON file, or database"""
 
     def __init__(self, csvpaths):
@@ -20,6 +20,7 @@ class FileRegistrar(Registrar, Listener):
         self.csvpaths = csvpaths
         self.config = csvpaths.config
         self.type_name = "file"
+        self.intermediary = Intermediary(csvpaths)
 
     def get_fingerprint(self, home) -> str:
         mpath = self.manifest_path(home)
@@ -31,17 +32,87 @@ class FileRegistrar(Registrar, Listener):
         return man[len(man) - 1]["fingerprint"]
 
     def manifest_path(self, home) -> str:
-        if not Nos(home).dir_exists():
+        if home is None or home.strip() == "":
+            raise ValueError("Home cannot be None or empty")
+        nos = Nos(home)
+        if nos.physical_dirs() and not nos.dir_exists():
             raise InputException(f"Named file home does not exist: {home}")
         mf = os.path.join(home, "manifest.json")
-        if not Nos(mf).exists():
-            with DataFileWriter(path=mf, mode="w") as writer:
-                writer.append("[]")
+        nos.path = mf
+        if not nos.exists():
+            self.intermediary.put_json(mf, [])
         return mf
 
     def get_manifest(self, mpath) -> list:
-        with DataFileReader(mpath) as reader:
-            return json.load(reader.source)
+        j = self.intermediary.get_json(mpath)
+        if j is None:
+            j = []
+            self.intermediary.put_json(mpath, j)
+        return j
+
+    def patch_named_file(self, *, name, patch, index=-1) -> None:
+        #
+        # TODO: distribute an metadata event to give metadata stores a
+        # chance to update their info re: the file
+        #
+        home = self.csvpaths.file_manager.named_file_home(name)
+        mp = self.manifest_path(home)
+        mani = self.get_manifest(mp)
+        index = len(mani) - 1 if index == -1 else index
+        if "type" in patch:
+            #
+            # obviously without a change in file_name the type is set in metadata only.
+            #
+            mani[index]["type"] = patch["type"]
+        if "file_name" in patch:
+            #
+            # blob stores handle directories differently from filesystems.
+            #
+            if mani[index]["file"].find("://") > -1:
+                self._patch_blob(mani, index, patch)
+            else:
+                self._patch_filesystem(mani, home=home, index=index, patch=patch)
+        self.intermediary.put_json(mp, mani)
+
+    def _patch_blob(self, mani: dict, index: int, patch: dict) -> None:
+        old = mani[index]["file"]
+        newhome = f"{os.path.dirname(mani[index]['file_home'])}/{patch['file_name']}"
+        nos = Nos(newhome)
+        if not nos.dir_exists():
+            nos.makedir()
+        new = f"{newhome}/{mani[index]['fingerprint']}.{mani[index]['type']}"
+        nos = Nos(old)
+        if not nos.exists():
+            raise ValueError("File not found: {old}")
+        nos.rename(new)
+        mani[index]["file"] = new
+        mani[index]["file_home"] = newhome
+
+    def _patch_filesystem(
+        self, mani: dict, *, home: str, index: int, patch: dict
+    ) -> None:
+        sep = os.sep
+        #
+        # we can assume that if we're setting the file name the type may have changed
+        # and could be a problem. so we rename to fingerprint + type based on current info.
+        # then we rename the file home to the new file name we've been given.
+        #
+        # 1. move file to fingerprint.type
+        # 2. move file home to home/new_file_name
+        #
+        old_file = mani[index]["file"]
+        new_file = f"{mani[index]['file_home']}{sep}{mani[index]['fingerprint']}.{mani[index]['type']}"
+        nos = Nos(None)
+        nos.path = old_file
+        nos.rename(new_file)
+        old_home = mani[index]["file_home"]
+        new_home = f"{home}{sep}{patch['file_name']}"
+        nos.path = old_home
+        nos.rename(new_home)
+        mani[index]["file_home"] = new_home
+        mani[index][
+            "file"
+        ] = f"{new_home}{sep}{mani[index]['fingerprint']}.{mani[index]['type']}"
 
     def metadata_update(self, mdata: Metadata) -> None:
         path = mdata.origin_path
@@ -55,14 +126,16 @@ class FileRegistrar(Registrar, Listener):
         mani["file"] = rpath
         mani["file_home"] = mdata.file_home
         mani["fingerprint"] = h
+        mani["uuid"] = mdata.uuid_string
         mani["time"] = mdata.time_string
         mani["from"] = path
         if mark is not None:
             mani["mark"] = mark
+        if mdata.template is not None:
+            mani["template"] = mdata.template
         jdata = self.get_manifest(manifest_path)
         jdata.append(mani)
-        with DataFileWriter(path=manifest_path, mode="w") as writer:
-            json.dump(jdata, writer.sink, indent=2)
+        self.intermediary.put_json(manifest_path, jdata)
         #
         # drop update into an all-inputs/files record here?
         #
@@ -70,6 +143,10 @@ class FileRegistrar(Registrar, Listener):
     def register_complete(self, mdata: Metadata) -> None:
         path = mdata.origin_path
         home = mdata.name_home
+        if path is None or path.strip() == "":
+            raise ValueError("Path cannot be None or empty")
+        if home is None or home.strip() == "":
+            raise ValueError("Home cannot be None or empty")
         i = path.find("#")
         mark = None
         if i > -1:
@@ -79,11 +156,14 @@ class FileRegistrar(Registrar, Listener):
             raise InputException(
                 f"File mgr and registrar marks should match: {mdata.mark}, {mark}"
             )
-        if not path.startswith("s3:") and not Nos(path).exists():
+        if (
+            # Nos doesn't handle http files. they are special--inbound only.
+            not path.startswith("http:")
+            and not path.startswith("https:")
+            and not Nos(path).exists()
+        ):
             # if not path.startswith("s3:") and not os.path.exists(path):
             #
-            # try for a data reader in case we're smart-opening
-            #
             raise InputException(f"Path {path} does not exist")
         #
         # if the fingerprint already exists we don't store the file again.
@@ -102,23 +182,26 @@ class FileRegistrar(Registrar, Listener):
         mdata.manifest_path = mpath
         mdata.type = self._type_from_sourcepath(path)
         jdata = self.get_manifest(mpath)
-        if len(jdata) > 0:
-            _ = jdata[len(jdata) - 1]
+        for _ in jdata:
+            #
             # if the fingerprints are the same and we haven't renamed
             # the file or moved all the files we don't need to reregister
             # this file. at least that is the thinking today. it is possible
             # we might want to reregister in the case of a new listener
             # being added or for some other reason, but not atm.
+            #
             if (
                 "fingerprint" in _
                 and _["fingerprint"] == mdata.fingerprint
                 and "file_home" in _
-                and _["file_home"] == mdata.file_home
+                and _["file_home"].lower() == mdata.file_home.lower()
             ):
                 #
-                # leave as info so nobody has to dig to see why no update
+                # log info so nobody has to dig to see why no update
                 #
-                self.csvpaths.logger.info("File has already been registered: %s", jdata)
+                self.csvpaths.logger.info(
+                    "File has already been registered: %s", mdata.name_home
+                )
                 return
         self.distribute_update(mdata)
 
@@ -139,19 +222,18 @@ class FileRegistrar(Registrar, Listener):
 
     def registered_file(self, home: str) -> str:
         mpath = self.manifest_path(home)
-        with DataFileReader(mpath) as reader:
-            mdata = json.load(reader.source)
-            if mdata is None or len(mdata) == 0:
-                raise InputException(f"Manifest for {home} at {mpath} is empty")
-            m = mdata[len(mdata) - 1]
-            if "file" not in m:
-                raise ValueError(
-                    "File path cannot be None. Check your config file and named-files."
-                )
-            path = m["file"]
-            mark = None
-            if "mark" in m:
-                mark = m["mark"]
-            if mark is not None:
-                path = f"{path}#{mark}"
-            return path
+        mdata = self.get_manifest(mpath)
+        if mdata is None or len(mdata) == 0:
+            raise InputException(f"Manifest for {home} at {mpath} is empty")
+        m = mdata[len(mdata) - 1]
+        if "file" not in m:
+            raise ValueError(
+                "File path cannot be None. Check your config file and named-files."
+            )
+        path = m["file"]
+        mark = None
+        if "mark" in m:
+            mark = m["mark"]
+        if mark is not None:
+            path = f"{path}#{mark}"
+        return path
