@@ -5,12 +5,13 @@ from ..util.config import Config
 
 class Listener(ABC):
     def __init__(self, config=None) -> None:
+        self._config = None
         super().__init__()
-        self._config = config
+        self.config = config
 
     @property
     def config(self):
-        if not self._config:
+        if self._config is None:
             #
             # this really should never happen. but perhaps in testing?
             #
@@ -23,7 +24,7 @@ class Listener(ABC):
 
     @abstractmethod
     def metadata_update(self, mdata: Metadata) -> None:
-        """any system that wants updates about a registrar's actions registers to
+        """any system that wants updates about a registrar or manager registers to
         receive updates. for e.g. an OpenLineage integration might register for
         named-results and other metadata to track jobs and datasets. the first
         registrar in the list of metadata receivers must be CsvPath Library's own
