@@ -2,6 +2,8 @@ from csvpath.managers.metadata import Metadata
 
 
 class PathsMetadata(Metadata):
+    """@private"""
+
     def __init__(self, config):
         super().__init__(config)
         self.named_paths_name: str = None
@@ -11,3 +13,4 @@ class PathsMetadata(Metadata):
         self.named_paths_identities: list[str] = None
         self.named_paths: list[str] = None
         self.source_path: str = None
+        self.template: str = None
