@@ -2,8 +2,8 @@ import os
 import json
 from csvpath.util.exceptions import InputException
 from csvpath.util.file_readers import DataFileReader
-from csvpath.util.file_writers import DataFileWriter
 from csvpath.util.nos import Nos
+from csvpath.util.intermediary import Intermediary
 from .paths_metadata import PathsMetadata
 from ..listener import Listener
 from ..metadata import Metadata
@@ -11,12 +11,14 @@ from ..registrar import Registrar
 
 
 class PathsRegistrar(Registrar, Listener):
+    """@private"""
+
     def __init__(self, csvpaths):
-        # super().__init__(csvpaths)
         Registrar.__init__(self, csvpaths)
         Listener.__init__(self, csvpaths.config)
         self._manager = None
         self.type_name = "paths"
+        self.intermediary = Intermediary(csvpaths)
 
     @property
     def manager(self):
@@ -25,16 +27,15 @@ class PathsRegistrar(Registrar, Listener):
         return self._manager
 
     def get_manifest(self, mpath) -> list:
-        with DataFileReader(mpath) as file:
-            j = json.load(file.source)
-            return j
+        j = self.intermediary.get_json(mpath)
+        return j
 
     def register_complete(self, mdata: Metadata) -> None:
         mdata.manifest_path = self.manifest_path(name=mdata.named_paths_name)
         mdata.fingerprint = self._fingerprint(name=mdata.named_paths_name)
         self.distribute_update(mdata)
 
-    def update_manifest_if(self, *, group_file_path, name, paths=None):
+    def update_manifest_if(self, *, group_file_path, name, paths):
         #
         # if we find that the current group file does not have the same
         # fingerprint as the most recent on file, we register a new version.
@@ -46,20 +47,19 @@ class PathsRegistrar(Registrar, Listener):
         mpath = self.manifest_path(name)
         cf = self._most_recent_fingerprint(mpath)
         if f != cf:
-            mdata = PathsMetadata()
+            mdata = PathsMetadata(self.csvpaths.config)
             mdata.archive_name = self.csvpaths.config.archive_name
             mdata.named_paths_name = name
-            #
-            # why two of these? :/
-            #
-            # mdata.named_paths_file = group_file_path
             mdata.group_file_path = group_file_path
             mdata.named_paths = paths
             mdata.named_paths_identities = [
-                t[0] for t in self.manager.get_identified_paths_in(name)
+                #
+                # if we don't pass paths to get_identified_paths_in we will infinite loop
+                #
+                t[0]
+                for t in self.manager.get_identified_paths_in(name, paths)
             ]
-            if paths:
-                mdata.named_paths_count = len(paths)
+            mdata.named_paths_count = len(paths)
             mdata.manifest_path = mpath
             mdata.fingerprint = f
             self.distribute_update(mdata)
@@ -99,9 +99,10 @@ class PathsRegistrar(Registrar, Listener):
                 m["time_completed"] = mdata.time_completed_string
             m["uuid"] = mdata.uuid_string
             m["manifest_path"] = mdata.manifest_path
+            if mdata.template is not None:
+                m["template"] = mdata.template
             jdata.append(m)
-            with DataFileWriter(path=mdata.manifest_path) as file:
-                json.dump(jdata, file.sink, indent=2)
+            self.intermediary.put_json(mdata.manifest_path, jdata)
         else:
             #
             # leave as info so nobody has to dig to see why no update
@@ -115,8 +116,7 @@ class PathsRegistrar(Registrar, Listener):
         nhome = self.manager.named_paths_home(name)
         mf = os.path.join(nhome, "manifest.json")
         if not Nos(mf).exists():
-            with DataFileWriter(path=mf) as file:
-                file.append("[]")
+            self.intermediary.put_json(mf, [])
         return mf
 
     def _most_recent_fingerprint(self, manifest_path: str) -> str:
