@@ -2,6 +2,7 @@
 import os
 from uuid import UUID
 import uuid
+import json
 from datetime import datetime
 from typing import Any
 from csvpath import CsvPath
@@ -14,6 +15,8 @@ from csvpath.util.exceptions import CsvPathsException
 from csvpath.util.line_spooler import LineSpooler, CsvLineSpooler
 from .result_serializer import ResultSerializer
 from .readers.readers import ResultReadersFacade
+from csvpath.matching.util.expression_utility import ExpressionUtility
+from csvpath.util.file_readers import DataFileReader
 
 
 class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
@@ -34,7 +37,9 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
         run_time: datetime = None,
         runtime_data: dict = None,
         by_line: bool = False,
+        run_uuid: UUID,
     ):
+        """@private"""
         ErrorCollector.__init__(self)
         Printer.__init__(self)
         Listener.__init__(self, csvpath.config if csvpath is not None else None)
@@ -96,6 +101,7 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
         self._unmatched: list[list[Any]] = None
         self._lines: list[list[Any]] = None
         self._readers_facade = ResultReadersFacade(self)
+        self._run_uuid = run_uuid
 
     @property
     def actual_data_file(self) -> str:
@@ -118,12 +124,24 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
             self._uuid = uuid.uuid4()
         return self._uuid
 
+    @property
+    def run_uuid(self) -> UUID:
+        if self._run_uuid is None:
+            self._run_uuid = uuid.uuid4()
+        return self._run_uuid
+
     @uuid.setter
     def uuid(self, u: UUID) -> None:
         if not isinstance(u, UUID):
             raise ValueError("Uuid must be a UUID")
         self._uuid = u
 
+    @run_uuid.setter
+    def run_uuid(self, u: UUID) -> None:
+        if not isinstance(u, UUID):
+            raise ValueError("Uuid must be a UUID")
+        self._run_uuid = u
+
     @property
     def run_time(self) -> datetime:
         return self._run_time
@@ -136,6 +154,13 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
     def run_dir(self, d: str) -> None:
         self._run_dir = d
 
+    @property
+    def run_manifest(self) -> dict:
+        p = self.run_dir
+        p = os.path.join(p, "manifest.json")
+        with DataFileReader(p) as reader:
+            return json.load(reader.source)
+
     @property
     def by_line(self) -> bool:
         return self._by_line
@@ -160,6 +185,13 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
         )
         return i_dir
 
+    @property
+    def manifest(self) -> dict:
+        p = self.instance_dir
+        p = os.path.join(p, "manifest.json")
+        with DataFileReader(p) as reader:
+            return json.load(reader.source)
+
     @property
     def identity_or_index(self) -> str:
         s = self._csvpath.identity
@@ -167,6 +199,15 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
             s = self.run_index
         return s
 
+    @property
+    def index(self) -> int:
+        ri = self.run_index
+        if ri is None:
+            return None
+        ri = ri.strip()
+        ri = ExpressionUtility.to_int(ri)
+        return ri
+
     @property
     def paths_name(self) -> str:  # pylint: disable=C0116
         return self._paths_name
@@ -175,6 +216,9 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
     def paths_name(self, paths_name: str) -> None:
         self._paths_name = paths_name  # pragma: no cover
 
+    #
+    # this is the named-file name, not a physical file name
+    #
     @property
     def file_name(self) -> str:  # pylint: disable=C0116
         return self._file_name
@@ -195,12 +239,14 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
 
     @property
     def last_line(self):  # pylint: disable=C0116
+        """@private"""
         return self._last_line
 
     #
     # =============== LISTENING ===============
     #
     def metadata_update(self, mdata: Metadata) -> None:
+        """@private"""
         if isinstance(mdata, Error):
             self.collect_error(mdata)
 
@@ -214,6 +260,7 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
 
     @csvpath.setter
     def csvpath(self, path: CsvPath) -> None:
+        """@private"""
         # during testing or for some other reason we may receive None
         # let's assume the dev knows what they're doing and just go with it.
         if path is not None:
@@ -265,6 +312,7 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
         return 0
 
     def collect_error(self, error: Error) -> None:  # pylint: disable=C0116
+        """@private"""
         if self.errors is not None:
             self.errors.append(error)
 
@@ -290,6 +338,7 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
         return []
 
     def set_printouts(self, name: str, lines: list[str]) -> None:
+        """@private"""
         self.printouts[name] = lines
 
     def has_printouts(self) -> bool:  # pylint: disable=C0116
@@ -301,12 +350,15 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
 
     @property
     def lines_printed(self) -> int:  # pylint: disable=C0116
+        """@private"""
         return self._print_count
 
     def print(self, string: str) -> None:  # pylint: disable=C0116
+        """@private"""
         self.print_to("default", string)
 
     def print_to(self, name: str, string: str) -> None:  # pylint: disable=C0116
+        """@private"""
         self._print_count += 1
         if name not in self.printouts:
             self.printouts[name] = []
@@ -314,12 +366,14 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
         self._last_line = string
 
     def dump_printing(self) -> None:  # pylint: disable=C0116
+        """@private"""
         for k, v in self.printouts.items():
             for line in v:
                 print(f"{k}: {line}")
             print("")
 
     def print_statements_count(self) -> int:  # pylint: disable=C0116
+        """@private"""
         i = 0
         for name in self.printouts:
             i += len(self.printouts[name]) if self.printouts[name] else 0
@@ -344,12 +398,14 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
         return self._lines
 
     @lines.setter
-    def lines(self, ls: list[list[Any]]) -> None:
+    def lines(self, ls: list[list[Any]] | LineSpooler) -> None:
+        """@private"""
         if self._lines and isinstance(self._lines, LineSpooler):
             self._lines.close()
         self._lines = ls
 
     def append(self, line: list[Any]) -> None:
+        """@private"""
         self.lines.append(line)
 
     def __len__(self) -> int:
@@ -357,6 +413,9 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
             if isinstance(self.lines, list):
                 return len(self.lines)
             i = 0
+            #
+            # is a LineSpooler
+            #
             for _ in self.lines.next():
                 i += 1
             return i
@@ -382,6 +441,7 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
 
     @unmatched.setter
     def unmatched(self, lines: list[list[Any]]) -> None:
+        """@private"""
         self._unmatched = lines
 
     #
@@ -403,6 +463,8 @@ class Result(ErrorCollector, Printer, Listener):  # pylint: disable=R0902
                    name of paths:{self.paths_name};
                    name of file:{self.file_name};
                    run results dir:{self.run_dir};
+                   index: {self.index};
+                   identity: {self.identity_or_index};
                    valid:{self.csvpath.is_valid};
                    stopped:{self.csvpath.stopped};
                    last line processed:{lastline};
