@@ -6,6 +6,8 @@ from csvpath.util.file_writers import DataFileWriter
 
 
 class ResultFileReader:
+    """@private"""
+
     @classmethod
     def json_file(self, path: str) -> dict | None:
         if not Nos(path).exists():
@@ -25,3 +27,8 @@ class ResultFileReader:
     def meta(self, result_home: str) -> dict | None:
         mp = os.path.join(result_home, "meta.json")
         return ResultFileReader.json_file(mp)
+
+    @classmethod
+    def vars(self, result_home: str) -> dict | None:
+        mp = os.path.join(result_home, "vars.json")
+        return ResultFileReader.json_file(mp)
