@@ -3,7 +3,10 @@ import json
 from datetime import datetime
 from csvpath.util.file_readers import DataFileReader
 from csvpath.util.file_writers import DataFileWriter
+from csvpath.util.references.reference_parser import ReferenceParser
 from csvpath.util.nos import Nos
+from csvpath.util.box import Box
+
 from ..listener import Listener
 from ..metadata import Metadata
 from ..registrar import Registrar
@@ -11,27 +14,39 @@ from .result_metadata import ResultMetadata
 
 
 class ResultRegistrar(Registrar, Listener):
+    """@private"""
+
     def __init__(self, *, csvpaths, result, result_serializer=None):
-        # super().__init__(csvpaths, result)
         Registrar.__init__(self, csvpaths, result)
         Listener.__init__(self, csvpaths.config)
         self.result_serializer = result_serializer
         self.type_name = "result"
+        self._nos = None
+
+    @property
+    def nos(self) -> Nos:
+        if self._nos is None:
+            box = Box()
+            self._nos = box.get("boto_s3_nos")
+            if self._nos is None:
+                self._nos = Nos(None)
+                box.add("boto_s3_nos", self._nos)
+        return self._nos
 
     def register_start(self, mdata: Metadata) -> None:
         p = self.named_paths_manifest
         mdata.by_line = self.result.by_line
+        mdata.run_uuid = self.result.run_uuid
         mdata.manifest_path = self.manifest_path
         mdata.instance_index = self.result.run_index
         mdata.actual_data_file = self.result.actual_data_file
         mdata.origin_data_file = self.result.origin_data_file
         ri = int(self.result.run_index) if self.result.run_index else 0
         if ri >= 1:
-            rs = self.result.csvpath.csvpaths.results_manager.get_named_results(
-                self.result.paths_name
+            pid = self.csvpaths.paths_manager.get_preceeding_instance_identity(
+                self.result.paths_name, ri
             )
-            r = rs[ri - 1]
-            mdata.preceding_instance_identity = r.identity_or_index
+            mdata.preceding_instance_identity = pid
         if p is None:
             self.result.csvpath.csvpaths.logger.debug(
                 "No named-paths manifest available at %s so not setting named_paths_uuid_string",
@@ -53,38 +68,59 @@ class ResultRegistrar(Registrar, Listener):
             mdata = ResultMetadata(config=self.csvpaths.config)
         mdata.from_manifest(m)
         mdata.archive_name = self.archive_name
-        mdata.named_results_name = self.result.paths_name
-        mdata.run = self.result_serializer.get_run_dir_name_from_datetime(
-            self.result.run_time
-        )
-        mdata.by_line = self.result.by_line
+        #
+        # if the paths_name has a $ we need to be more general
+        #
+        if "$" in self.result.paths_name:
+            ref = ReferenceParser(self.result.paths_name)
+            mdata.named_results_name = ref.root_major
+        else:
+            mdata.named_results_name = self.result.paths_name
+
+        mdata.named_paths_name = self.result.paths_name
+        mdata.named_paths_uuid_string = self.csvpaths.run_metadata.named_paths_uuid
+        mdata.named_file_name = self.result.file_name
+        mdata.named_file_uuid = self.csvpaths.run_metadata.named_file_uuid
+        #
+        # exp. swapping for the original above. no negative impact. logically it's the better way.
+        #
+        mdata.run_dir = self.result.run_dir
+        #
+        # end exp
+        #
         mdata.source_mode_preceding = self.result.source_mode_preceding
         mdata.run_home = self.result.run_dir
+        mdata.run_uuid_string = self.csvpaths.run_metadata.run_uuid_string
         mdata.instance_home = self.result.instance_dir
         mdata.instance_identity = self.result.identity_or_index
         mdata.instance_index = self.result.run_index
-        mdata.named_file_name = self.result.file_name
-        mdata.input_data_file = self.result.file_name
         mdata.file_fingerprints = self.file_fingerprints
-        mdata.file_count = len(mdata.file_fingerprints)
         mdata.error_count = self.result.errors_count
         mdata.valid = self.result.csvpath.is_valid
         mdata.completed = self.completed
         mdata.files_expected = self.all_expected_files
+        mdata.number_of_files_expected = len(self.result.csvpath.all_expected_files)
+        mdata.number_of_files_generated = self.number_of_files_generated()
+        mdata.lines_total = self.result.csvpath.line_monitor.physical_line_count
+        mdata.lines_scanned = self.result.csvpath.scan_count
+        mdata.lines_matched = self.result.csvpath.match_count
         if self.result.csvpath.transfers:
             tpaths = self.result.csvpath.csvpaths.results_manager.transfer_paths(
                 self.result
             )
             mdata.transfers = tpaths
+        #
+        # input_data_file is deprecated in favor of named_file_name. but atm still used.
+        #
+        mdata.input_data_file = self.result.file_name
         mdata.actual_data_file = self.result.actual_data_file
         mdata.origin_data_file = self.result.origin_data_file
         ri = int(self.result.run_index) if self.result.run_index else 0
         if ri >= 1:
-            rs = self.result.csvpath.csvpaths.results_manager.get_named_results(
-                self.result.paths_name
+            pid = self.csvpaths.paths_manager.get_preceeding_instance_identity(
+                self.result.paths_name, ri
             )
-            r = rs[ri - 1]
-            mdata.preceding_instance_identity = r.identity_or_index
+            mdata.preceding_instance_identity = pid
         self.distribute_update(mdata)
 
     def metadata_update(self, mdata: Metadata) -> None:
@@ -98,13 +134,15 @@ class ResultRegistrar(Registrar, Listener):
         m["named_results_name"] = mdata.named_results_name
         m["named_paths_uuid"] = mdata.named_paths_uuid_string
         m["run"] = mdata.run
+        m["run_uuid"] = mdata.run_uuid_string
         m["run_home"] = mdata.run_home
         m["instance_identity"] = mdata.instance_identity
         m["instance_index"] = mdata.instance_index
         m["instance_home"] = mdata.instance_home
         m["file_fingerprints"] = mdata.file_fingerprints
         m["files_expected"] = mdata.files_expected
-        m["file_count"] = mdata.file_count
+        m["number_of_files_expected"] = mdata.number_of_files_expected
+        m["number_of_files_generated"] = mdata.number_of_files_generated
         m["valid"] = mdata.valid
         m["completed"] = mdata.completed
         m["source_mode_preceding"] = mdata.source_mode_preceding
@@ -123,7 +161,9 @@ class ResultRegistrar(Registrar, Listener):
     @property
     def archive_name(self) -> str:
         ap = self.result.csvpath.config.archive_path
-        sep = Nos(ap).sep
+        nos = self.nos
+        nos.path = ap
+        sep = nos.sep
         i = ap.rfind(sep)
         if i > 0:
             return ap[i + 1 :]
@@ -132,7 +172,9 @@ class ResultRegistrar(Registrar, Listener):
     # gets the manifest for the named_paths as a whole
     @property
     def named_paths_manifest(self) -> dict | None:
-        if Nos(self.named_paths_manifest_path).exists():
+        nos = self.nos
+        nos.path = self.named_paths_manifest_path
+        if nos.exists():
             with DataFileReader(self.named_paths_manifest_path) as file:
                 d = json.load(file.source)
                 return d
@@ -149,7 +191,9 @@ class ResultRegistrar(Registrar, Listener):
     @property
     def manifest(self) -> dict | None:
         mp = self.manifest_path
-        if not Nos(mp).exists():
+        nos = self.nos
+        nos.path = mp
+        if not nos.exists():
             with DataFileWriter(path=self.manifest_path) as file:
                 json.dump({}, file.sink, indent=2)
                 return {}
@@ -168,8 +212,10 @@ class ResultRegistrar(Registrar, Listener):
         rdir = self.result_serializer.get_instance_dir(
             run_dir=self.result.run_dir, identity=self.result.identity_or_index
         )
-        if not Nos(rdir).exists():
-            Nos(rdir).makedir()
+        nos = self.nos
+        nos.path = rdir
+        if not nos.exists():
+            nos.makedir()
         return rdir
 
     @property
@@ -178,6 +224,9 @@ class ResultRegistrar(Registrar, Listener):
 
     @property
     def all_expected_files(self) -> bool:
+        #
+        # True if the files in files-mode are all present. we can have more than those
+        # listed files, but if we're missing any that are listed we return False.
         #
         # we can not have any/all of data.csv, unmatched.csv, and printouts.txt without
         # it necessarily being a failure mode. but we can require them as a matter of
@@ -222,9 +271,21 @@ class ResultRegistrar(Registrar, Listener):
                 return False
         return True
 
+    def number_of_files_generated(self) -> int:
+        n = 0
+        n += 1 if self.has_file("meta.json") else 0
+        n += 1 if self.has_file("errors.json") else 0
+        n += 1 if self.has_file("vars.json") else 0
+        n += 1 if self.has_file("data.csv") else 0
+        n += 1 if self.has_file("unmatched.csv") else 0
+        n += 1 if self.has_file("printouts.txt") else 0
+        return n
+
     def has_file(self, t: str) -> bool:
         r = self.result_path
-        return Nos(os.path.join(r, t)).exists()
+        nos = self.nos
+        nos.path = os.path.join(r, t)
+        return nos.exists()
 
     @property
     def file_fingerprints(self) -> dict[str]:
@@ -247,7 +308,9 @@ class ResultRegistrar(Registrar, Listener):
     def _fingerprint(self, path) -> str:
         if path.find("://") == -1 and not path.startswith("/"):
             path = f"{os.getcwd()}/{path}"
-        if Nos(path).exists():
+        nos = self.nos
+        nos.path = path
+        if nos.exists():
             with DataFileReader(path) as f:
                 h = f.fingerprint()
                 return h
