@@ -1,16 +1,23 @@
 # pylint: disable=C0114
 import os
+import json
+import re
+from uuid import UUID
 from pathlib import Path
 import datetime
 import dateutil.parser
 from typing import Dict, List, Any
 from csvpath.util.line_spooler import LineSpooler
 from csvpath.util.exceptions import InputException, CsvPathsException
-from csvpath.util.reference_parser import ReferenceParser
+from csvpath.util.references.reference_parser import ReferenceParser
+from csvpath.util.references.results_reference_finder_2 import (
+    ResultsReferenceFinder2 as ResultsReferenceFinder,
+)
 from csvpath.util.file_readers import DataFileReader
 from csvpath.util.file_writers import DataFileWriter
 from csvpath.util.nos import Nos
-from csvpath.scanning.scanner import Scanner
+
+from csvpath.scanning.scanner2 import Scanner2 as Scanner
 from ..run.run_metadata import RunMetadata
 from ..run.run_registrar import RunRegistrar
 from .results_metadata import ResultsMetadata
@@ -20,24 +27,31 @@ from .result_registrar import ResultRegistrar
 from .result_serializer import ResultSerializer
 from .result import Result
 from .result_file_reader import ResultFileReader
+from csvpath.util.template_util import TemplateUtility as temu
 
 
 class ResultsManager:  # pylint: disable=C0115
     def __init__(self, *, csvpaths=None):
+        """@private"""
         self.named_results = {}
+        """@private"""
         self._csvpaths = None
         # use property
         self.csvpaths = csvpaths
+        """@private"""
 
     @property
     def csvpaths(self):
+        """@private"""
         return self._csvpaths
 
     @csvpaths.setter
     def csvpaths(self, cs) -> None:  # noqa: F821
+        """@private"""
         self._csvpaths = cs
 
     def complete_run(self, *, run_dir, pathsname, results) -> None:
+        """@private"""
         rr = ResultsRegistrar(
             csvpaths=self.csvpaths,
             run_dir=run_dir,
@@ -58,44 +72,111 @@ class ResultsManager:  # pylint: disable=C0115
         mdata.named_file_path = m["named_file_path"]
         mdata.run_home = run_dir
         mdata.named_paths_name = pathsname
-        mdata.named_results_name = pathsname
+        if "$" in pathsname:
+            mdata.named_results_name = ReferenceParser(pathsname).root_major
+        else:
+            mdata.named_results_name = pathsname
+        mdata.number_of_files_expected = -1
+        mdata.number_of_files_generated = -1
+
         rr.register_complete(mdata)
 
-    def start_run(self, *, run_dir, pathsname, filename) -> None:
+    #
+    # since the filename may be a reference that picks out multiple files
+    # we pass the physical data file. if file_manager receives that it
+    # will look in the named-file manifest for the registration that matches
+    # and return that uuid.
+    #
+    def start_run(
+        self, *, run_dir, pathsname, filename, file: str = None, run_uuid: UUID
+    ) -> None:
+        """@private"""
         rr = ResultsRegistrar(
             csvpaths=self.csvpaths,
             run_dir=run_dir,
             pathsname=pathsname,
         )
+        #
+        # collect the named-paths and named-file uuids. these may
+        # need to come from a different source at some point but
+        # pulling them from the managers insulates us a bit.
+        #
+        np_uuid = self.csvpaths.paths_manager.get_named_paths_uuid(pathsname)
+        if np_uuid is None:
+            raise ValueError("named_paths_uuid cannot be None")
+        f_uuid = self.csvpaths.file_manager.get_named_file_uuid(
+            name=filename, file=file
+        )
+        if f_uuid is None:
+            raise ValueError("named_file_uuid cannot be None")
+        #
+        #
+        #
         mdata = ResultsMetadata(self.csvpaths.config)
         mdata.archive_name = self.csvpaths.config.archive_name
-        mdata.named_file_name = filename
         mdata.run_home = run_dir
+        mdata.run_uuid = run_uuid
+        mdata.named_file_name = filename
+        mdata.named_file_uuid = f"{f_uuid}"
         mdata.named_paths_name = pathsname
+        mdata.named_paths_uuid = f"{np_uuid}"
         mdata.named_results_name = pathsname
         rr.register_start(mdata)
+        return mdata
 
-    def get_metadata(self, name: str) -> Dict[str, Any]:
-        """gets the run metadata. will include the metadata complete from
-        the first results. however, the metadata for individual results must
-        come direct from them in order to not overwrite"""
+    #
+    # this new version gets all the metadata from first through last member of the
+    # named-paths group. last key added wins. if you need to be sure one csvpath
+    # doesn't stomp on the last iterate the result objects yourself.
+    #
+    def get_metadata(self, name: str) -> bool:
         results = self.get_named_results(name)
-        meta = {}
-        if results and len(results) > 0:
-            rs = results[0]
-            path = rs.csvpath
-            meta["paths_name"] = rs.paths_name
-            meta["file_name"] = rs.file_name
-            meta["data_lines"] = path.line_monitor.data_end_line_count
-            paths = len(self.csvpaths.paths_manager.get_named_paths(name))
-            meta["csvpaths_applied"] = paths
-            meta["csvpaths_completed"] = paths == len(results)
-            meta["valid"] = self.is_valid(name)
-            meta = {**meta, **rs.csvpath.metadata}
-        return meta
+        vs = {}
+        for r in results:
+            vs = {**r.csvpath.metadata, **vs}
+        return vs
 
-    def get_specific_named_result(self, name: str, name_or_id: str) -> Result:
+    #
+    # unlike get_variables and get_metadata, get_errors adds lists with no chance for loss.
+    #
+    def get_errors(self, name: str) -> bool:
         results = self.get_named_results(name)
+        es = []
+        for r in results:
+            es += r.csvpath.errors
+        return es
+
+    def get_specific_named_result(self, name: str, name_or_id: str = None) -> Result:
+        #
+        # ideally we need to handle two things:
+        #   1: name=mygroup, name_or_id=myinstance
+        #   2: $mygroup.results.path-to-run_dir.myinstance#[variables|headers|csvpath|metadata|errors|printouts]
+        #
+
+        if name is None:
+            raise ValueError("Name cannot be none")
+        if name_or_id is None:
+            if name.startswith("$"):
+                ref = ReferenceParser(name, csvpaths=self.csvpaths)
+                if ref.root_minor is not None:
+                    name_or_id = ref.root_minor
+                elif ref.name_three is not None:
+                    name_or_id = ref.name_three
+                else:
+                    #
+                    # assuming the instance name_or_id is in the ref's name_one,
+                    # this could be reasonable. or it may be user-error. if the user
+                    # really wanted a date or template path to run_dir, this would be
+                    # off base. but if they are looking for just the most recent run's
+                    # instance it would at least make sense, but, regardless, would
+                    # still not be ok.
+                    #
+                    raise ValueError("You must identity which run")
+        if name_or_id is None:
+            raise ValueError("Instance name cannot be none")
+        results = self.get_named_results(name)
+        if results is not None and not isinstance(results, list):
+            return results
         if results and len(results) > 0:
             for r in results:
                 if name_or_id == r.csvpath.identity:
@@ -112,6 +193,10 @@ class ResultsManager:  # pylint: disable=C0115
         rr = ResultRegistrar(csvpaths=self.csvpaths, result=r, result_serializer=rs)
         return rr.manifest
 
+    #
+    # returns the last run of name's last csvpath instance result object.
+    # seems like an odd use case to support with its own method. needed?
+    #
     def get_last_named_result(self, *, name: str, before: str = None) -> Result:
         results = self.get_named_results(name)
         if results and len(results) > 0:
@@ -133,6 +218,7 @@ class ResultsManager:  # pylint: disable=C0115
         return vs
 
     def has_lines(self, name: str) -> bool:
+        """@private"""
         results = self.get_named_results(name)
         for r in results:
             if r.lines and len(r.lines) > 0:
@@ -160,6 +246,7 @@ class ResultsManager:  # pylint: disable=C0115
         return errors
 
     def add_named_result(self, result: Result) -> None:
+        """@private"""
         if result.file_name is None:
             raise InputException("Results must have a named-file name")
         if result.paths_name is None:
@@ -176,9 +263,9 @@ class ResultsManager:  # pylint: disable=C0115
         # the archive. the run's own more complete record is below as a
         # separate event. this could change, but atm seems reasonable.
         #
-
         mdata = RunMetadata(self.csvpaths.config)
         mdata.uuid = result.uuid
+        mdata.run_uuid = result.run_uuid
         mdata.archive_name = self.csvpaths.config.archive_name
         mdata.archive_path = self.csvpaths.config.archive_path
         mdata.time_start = result.run_time
@@ -188,16 +275,15 @@ class ResultsManager:  # pylint: disable=C0115
         mdata.named_file_name = result.file_name
         rr = RunRegistrar(self.csvpaths)
         rr.register_start(mdata)
-
         #
         # we prep the results event
         #
         # we use the same UUID for both metadata updates because the
         # UUID represents the run, not the metadata object
         #
-
         mdata = ResultMetadata(self.csvpaths.config)
         mdata.uuid = result.uuid
+        mdata.run_uuid = result.run_uuid
         mdata.archive_name = self.csvpaths.config.archive_name
         mdata.time_started = result.run_time
         mdata.named_results_name = result.paths_name
@@ -214,22 +300,44 @@ class ResultsManager:  # pylint: disable=C0115
         rr.register_start(mdata)
 
     def set_named_results(self, results: Dict[str, List[Result]]) -> None:
+        """@private"""
         self.named_results = {}
         for value in results.values():
             self.add_named_results(value)
 
     def add_named_results(self, results: List[Result]) -> None:
+        """@private"""
         for r in results:
             self.add_named_result(r)
 
+    #
+    # this name is somewhat confusing. we're listing the names of results, not the
+    # runs of the names. that means we're returning the flat list of paths-names/
+    # results-names directly below the archive root. if we were listing actual runs
+    # the challenge would be greater because templates allow for different structures
+    # below the flat named-results list, but that's not what we're doing.
+    #
     def list_named_results(self) -> list[str]:
         path = self._csvpaths.config.archive_path
-        names = Nos(path).listdir()
-        names = [n for n in names if not n.startswith(".")]
-        names.sort()
+        if Nos(path).dir_exists():
+            names = Nos(path).listdir()
+            #
+            # listing dir shouldn't return manifest.json or any file. can do better here.
+            #
+            names = [
+                n for n in names if not n.startswith(".") and not n.endswith(".json")
+            ]
+            names.sort()
+        else:
+            self._csvpaths.logger.warning(
+                "Archive %s does not exist. If no runs have been attempted yet this is fine.",
+                path,
+            )
+            names = []
         return names
 
     def do_transfers_if(self, result) -> None:
+        """@private"""
         transfers = result.csvpath.transfers
         if transfers is None:
             return
@@ -237,6 +345,7 @@ class ResultsManager:  # pylint: disable=C0115
         self._do_transfers(tpaths)
 
     def transfer_paths(self, result) -> list[tuple[str, str, str, str]]:
+        """@private"""
         #
         # 1: filename, no extension needed: data | unmatched
         # 2: variable name containing the path to write to
@@ -254,14 +363,16 @@ class ResultsManager:  # pylint: disable=C0115
         return tpaths
 
     def _do_transfers(self, tpaths) -> None:
+        """@private"""
         for t in tpaths:
             pathfrom = t[2]
             pathto = t[3]
             with DataFileReader(pathfrom) as pf:
-                with DataFileWriter(path=pathto, mode="w") as pt:
-                    pt.write(pf.read())
+                dfw = DataFileWriter(path=pathto, mode="w")
+                dfw.write(pf.read())
 
     def _path_to_transfer_to(self, result, t) -> str:
+        """@private"""
         p = result.csvpath.config.transfer_root
         if t not in result.csvpath.variables:
             raise InputException(f"Variable {t} not found in variables")
@@ -276,6 +387,7 @@ class ResultsManager:  # pylint: disable=C0115
         return rp
 
     def _path_to_result(self, result, t) -> str:
+        """@private"""
         d = result.instance_dir
         o = os.path.join(d, t)
         sep = Nos(o).sep
@@ -286,10 +398,10 @@ class ResultsManager:  # pylint: disable=C0115
         return o
 
     def save(self, result: Result) -> None:
+        """@private"""
         #
-        # at this time we're not holding on to the result.
-        # we have a place for that, but for now not holding
-        # forces the deserialization to work completely, so
+        # at this time we're not holding on to the result. we have a place for that,
+        # but for now not holding forces the deserialization to work completely, so
         # it is worth more than the minor speed up of caching.
         #
         if self._csvpaths is None:
@@ -298,9 +410,8 @@ class ResultsManager:  # pylint: disable=C0115
             # we are done spooling. need to close whatever may be open.
             result.lines.close()
             # cannot make lines None w/o recreating lines. now we're setting
-            # closed to true to indicate that we've written.
-            # we don't need the serializer trying to save spooled lines
-            # result.lines = None
+            # closed to true to indicate that we've written. we don't need the
+            # serializer trying to save spooled lines result.lines = None
         #
         # if we are doing a transfer(s) do it here so we can put metadata in about
         # the copy before the metadata is serialized into the results.
@@ -312,214 +423,204 @@ class ResultsManager:  # pylint: disable=C0115
             csvpaths=self.csvpaths, result=result, result_serializer=rs
         ).register_complete()
 
-    # in this form: $group.results.2024-01-01_10-15-20.mypath
-    def data_file_for_reference(self, refstr, not_name: str = None) -> str:
-        ref = ReferenceParser(refstr)
-        if ref.datatype != ReferenceParser.RESULTS:
-            raise InputException(
-                f"Reference datatype must be {ReferenceParser.RESULTS}"
-            )
-        namedpaths = ref.root_major
-        instance = ref.name_one
-        path = ref.name_three  # not used? why?
-        name_three = ref.name_three
-        base = self._csvpaths.config.archive_path
-        filename = os.path.join(base, namedpaths)
-        if not Nos(filename).dir_exists():
-            raise InputException(
-                f"Reference {refstr} generated {filename} path that does not point to a previously run named-paths group"
-            )
-        #
-        # instance can have var-subs like:
-        #   2024-01-01_10-15-:last
-        #   2024-01-01_10-:first
-        #   2024-01-01_10-:0
-        #
-        instance = self._find_instance(
-            filename, instance, not_name=not_name, name_three=name_three
-        )
-        filename = os.path.join(filename, instance)
-        if not Nos(filename).dir_exists():
-            raise InputException(
-                f"Reference {refstr} does not point to a valid named-paths run file at {filename}"
-            )
-        filename = os.path.join(filename, path)
-        if not Nos(filename).dir_exists():
-            raise InputException(
-                f"Reference to {filename} does not point to a csvpath in a named-paths group run"
-            )
-        filename = os.path.join(filename, "data.csv")
-        if not Nos(filename).exists():
-            raise InputException(
-                "Reference does not point to a data file resulting from a named-paths group run"
-            )
-        return filename
-
-    def _find_instance(
-        self, filename, instance, not_name: str = None, name_three: str = None
-    ) -> str:
-        """remember that you cannot replay a replay using :last. the reason is that both
-        runs will be looking for the same assets but the last replay run will not have
-        the asset needed. in principle, we could fix this, but in practice, any magic
-        we do to make it always work is going to make the lineage more mysterious.
-        """
-        c = instance.find(":")
-        if c == -1:
-            filename = os.path.join(filename, instance)
-            return filename
-        if not Nos(filename).dir_exists():
-            raise InputException(f"The base dir {filename} must exist")
-        var = instance[c:]
-        instance = instance[0:c]
-        ret = None
-        if var == ":last":
-            ret = self._find_last(
-                filename, instance, not_name=not_name, name_three=name_three
-            )
-        elif var == ":first":
-            ret = self._find_first(
-                filename, instance, not_name=not_name, name_three=name_three
-            )
-        else:
-            raise InputException(f"Unknown reference var-sub token {var}")
-        return ret
-
-    def _find_last(
-        self, filename, instance, not_name: str = None, name_three: str = None
-    ) -> str:
-        last = True
-        return self._find(
-            filename, instance, last, not_name=not_name, name_three=name_three
-        )
-
-    def _find_first(
-        self, filename, instance, not_name: str = None, name_three: str = None
-    ) -> str:
-        first = False
-        return self._find(
-            filename, instance, first, not_name=not_name, name_three=name_three
-        )
-
-    def _find(
-        self,
-        filename,
-        instance,
-        last: bool = True,
-        not_name: str = None,
-        name_three: str = None,
-    ) -> str:
-        names = Nos(filename).listdir()
-        ns = []
-        for n in names:
-            if not_name is not None and not_name.endswith(n):
-                continue
-            if n.startswith("."):
-                continue
-            #
-            # test for manifest existing here?
-            #
-            mani = os.path.join(filename, n)
-            mani = os.path.join(mani, "manifest.json")
-            if not Nos(mani).exists():
-                continue
-            if name_three:
-                mani = os.path.join(filename, n)
-                mani = os.path.join(mani, name_three)
-                mani = os.path.join(mani, "manifest.json")
-                if not Nos(mani).exists():
-                    continue
-            ns.append(n)
-        return self._find_in_dir_names(instance, ns, last)
-
-    def _find_in_dir_names(self, instance: str, names, last: bool = True) -> str:
-        ms = "%Y-%m-%d_%H-%M-%S.%f"
-        s = "%Y-%m-%d_%H-%M-%S"
-        names = [n for n in names if n.startswith(instance)]
-        if len(names) == 0:
-            return None
-        names = sorted(
-            names,
-            key=lambda x: datetime.datetime.strptime(x, ms if x.find(".") > -1 else s),
-        )
-        if last is True:
-            i = len(names)
-            #
-            # we drop 1 because -1 for the 0-base. note that we may find a replay
-            # run that doesn't have the asset we're looking for. that's not great
-            # but it is fine -- the rule is, no replays of replays using :last.
-            # it is on the user to set up their replay approprately.
-            #
-            i -= 1
-            if i < 0:
-                self.csvpaths.logger.error(
-                    f"Previous run is at count {i} but there is no such run. Returning None."
-                )
-                self.csvpaths.logger.info(
-                    "Found previous runs: %s matching instance: %s", names, instance
-                )
-                return None
-            ret = names[i]
-        else:
-            ret = names[0]
-        return ret
-
-    def get_run_time_str(self, name, run_time) -> str:
-        rs = ResultSerializer(self._csvpaths.config.archive_path)
-        t = rs.get_run_dir(paths_name=name, run_time=run_time)
-        return t
-
     def remove_named_results(self, name: str) -> None:
-        #
-        # does not get rid of results on disk
-        #
+        """@private"""
         if name in self.named_results:
             del self.named_results[name]
             self._variables = None
         else:
             self.csvpaths.logger.warning(f"Results '{name}' not found")
-            #
-            # we treat this as a recoverable error because typically the user
-            # has complete control of the csvpaths environment, making the
-            # problem config that should be addressed.
-            #
-            # if reached by a reference this error should be trapped at an
-            # expression and handled according to the error policy.
-            #
-            raise InputException(f"Results '{name}' not found")
+        path = self.get_named_results_home(name)
+        if path is None:
+            return
+        nos = Nos(path)
+        if nos.dir_exists():
+            nos.remove()
 
+    #
+    # @deprecated. use remove_named_results
+    #
     def clean_named_results(self, name: str) -> None:
+        """@private"""
         if name in self.named_results:
             self.remove_named_results(name)
-            #
-            # clean from filesystem too?
-            #
 
+    def all_run_dir_names(self, path, count) -> dict:
+        mydirs = {}
+        if count >= 0:
+            nos = Nos(path)
+            dirs = nos.listdir(dirs_only=True, recurse=True)
+            for d in dirs:
+                m = re.search(r"^.*\d{4}-\d{2}-\d{2}_\d{2}-\d{2}-\d{2}(_\d)?", d)
+                if m is not None:
+                    d = m.group(0)
+                    name = os.path.basename(d)
+                    mydirs[name] = d
+        else:
+            mydirs[os.path.dirname(path)] = path
+        return mydirs
+
+    def _get_named_results_for_reference(self, name: str) -> List[List[Any]]:
+        #
+        # $mygroup.results.orders/acme/2025:first.myinstance
+        #
+        ref = ReferenceParser(name, csvpaths=self.csvpaths)
+        if ref.datatype == ref.RESULTS:
+            reff = ResultsReferenceFinder(self.csvpaths, reference=name)
+            #
+            # we don't need the finder to identify the instance. we'll do
+            # ourselves. which is helpful if we're using name_four. the
+            # suffix is a nagging worry.
+            #
+            results = reff.query()
+            #
+            # name = the named-paths / named-results name
+            # run = the path to run_dir minus the archive/name root
+            # path = the full path to the run_dir
+            if len(results.files) == 0:
+                msg = f"Results '{name}' does not exist"
+                self.csvpaths.logger.error(msg)
+                if self.csvpaths.ecoms.do_i_raise():
+                    raise InputException(msg)
+            path = results.files[0]
+            run = path[len(self.csvpaths.config.archive_name) :]
+            nos = Nos(path)
+            run = run[run.find(nos.sep) + 1 :]
+            #
+            #
+            #
+            if ref.name_three is None:
+                return self._get_named_results_for_run(
+                    name=ref.root_major, run=run, path=path
+                )
+            if path.endswith(ref.name_three):
+                path = os.path.dirname(path)
+            return self.get_named_result_for_instance(
+                name=ref.root_major, run_dir=path, run=run, instance=ref.name_three
+            )
+        elif ref.datatype == ref.CSVPATHS:
+            #
+            # if we're trying to get results using a named-paths reference
+            # we must be reusing a named-paths reference that started the run
+            # in that case, we're just looking for the named-paths name, not
+            # anything more specific, so we'll try again passing only the
+            # root, the named-paths name.
+            #
+            return self.get_named_results(ref.root_major)
+        else:
+            raise ValueError(f"Unexpected reference datatype in: {ref}")
+
+    #
+    # effectively, get last named results. use reference for anything more specific.
+    #
+    # this gets the results of a run. it does not get the runs under the name.
+    #
     def get_named_results(self, name) -> List[List[Any]]:
         #
+        # as it turns out, references are (finally!) the easiest, so let's do that
+        # first.
+        #
+        if name is None:
+            raise ValueError("Name cannot be None")
+        if name.startswith("$"):
+            return self._get_named_results_for_reference(name)
+        #
         # CsvPaths instances should not be long lived. they are not servers or
         # agents. for each new run, unless there is a reason to not create a new
         # CsvPaths instance, we would create a new one.
         #
+        """ """
         if name in self.named_results:
-            return self.named_results[name]
+            #
+            # exp. removed 4 May.
+            # was/is this ever a good idea?
+            #
+            # seems to be important for a handful of unit tests.
+            #
+            rs = self.named_results[name]
+            return rs
+        """ """
         #
-        # find and load the result, if exists. we find
-        # results home with the name. run_home is the
-        # last run dir. the results we're looking for are
-        # the instance dirs in the run dir.
-        # we'll need another method for getting a specific
-        # run, rather than the default, the last one.
+        # find and load the result, if exists. we find results home with the name. run_home is the
+        # last run dir. the results we're looking for are the instance dirs in the run dir.
+        # we'll need another method for getting a specific run, rather than the default, the last one.
+        #
+        # use r̶u̶n̶_̶h̶o̶m̶e̶_̶m̶a̶k̶e̶r̶.r̶u̶n̶s̶_̶h̶o̶m̶e̶_̶f̶r̶o̶m̶_̶t̶e̶m̶p̶l̶a̶t̶e̶ OR an index.json in the named-results root to
+        # find the parent of the runs do the join below with that.
         #
         path = os.path.join(self.csvpaths.config.archive_path, name)
         self.csvpaths.logger.debug(
             "Attempting to load results for %s from %s", name, path
         )
-        runs = Nos(path).listdir()
-        runs.sort()
-        run = runs[len(runs) - 1]
-        rs = self.get_named_results_for_run(name=name, run=run)
-        if rs is not None:
-            return rs
+        #
+        # find the template. it comes from the named-paths so from the named-paths mgr
+        #
+        template = self._csvpaths.paths_manager.get_template_for_paths(name)
+        if template is not None and not template == "":
+            temu.valid(template)
+        else:
+            template = ""
+        #
+        # we should check here to make sure the template ends with :run_dir. that is a
+        # requirement as of June 2025. it is basically the same as :filename in named-files
+        # templates. originally there could be additional directories below :run_dir, but
+        # that makes trouble with the new grammar-based refs and in any case was always
+        # pretty illogical.
+        #
+        #
+        # "top" of template. inserted dirs
+        #
+        run = None
+        if template is not None and not template.strip() == "":
+            #
+            # TODO: there were concerns here pre-complete re the template changes.
+            #
+            t = template[0 : template.find(":run_dir")]
+            t2 = template[template.find(":run_dir") + 8 :]
+            c = t.count("/")  # or \\?
+            c = c if c > -1 else t.count("\\")
+            #
+            # problem is here: vvvvv in all_run_dir_names()
+            #
+            runs = self.all_run_dir_names(path, c)
+            names = list(runs.keys())
+            #
+            # there should be only run_dir names in names here. we sort based on
+            # them. but we need to get the original template-based name. i.e. we
+            # want 'aprx/2025-01-01...' not just '2025-01-01...'. that means we
+            # need the full template name and then sort on the os.path.dirname(path).
+            #
+            # atm, all_run_dir_names() is not giving the full template name. and
+            # it is also giving us names of instances within run_dirs. why? we
+            # definitely don't want those.
+            #
+            names.sort()
+            run = ""
+            if len(names) > 0:
+                run = names[len(names) - 1]
+            rpath = runs[run]
+            rpath = rpath[len(path) + 1 :]
+            if t2 and len(t2) > 0:
+                rpath = f"{rpath}{t2}"
+            run = rpath
+        else:
+            #
+            # original pre-template logic
+            #
+            nos = Nos(path)
+            exists = nos.dir_exists()
+            nonphy = nos.physical_dirs()
+            #
+            # is not nonphy needed?
+            #
+            if exists or not nonphy:
+                runs = nos.listdir()
+                if len(runs) > 0:
+                    runs.sort()
+                    run = runs[len(runs) - 1]
+        results = self.get_named_results_for_run(name=name, run=run)
+        if results is not None:
+            return results
         #
         # we treat this as a recoverable error because typically the user
         # has complete control of the csvpaths environment, making the
@@ -528,28 +629,65 @@ class ResultsManager:  # pylint: disable=C0115
         # if reached by a reference this error should be trapped at an
         # expression and handled according to the error policy.
         #
-        raise InputException(
-            f"Results '{name}' not found. Named-results are: {self.named_results}"
+        msg = (
+            f"Results '{name}' does not exist. Has has that named-paths group been run?"
         )
+        self.csvpaths.logger.warning(msg)
+        #
+        # it seems reasonable to request results that don't exist, if not ideal. a warn
+        # should be good enough, probably.
+        #
+        # if self.csvpaths.ecoms.do_i_raise():
+        #    raise InputException(msg)
+
+    def get_named_results_home(self, name: str) -> str:
+        path = os.path.join(self.csvpaths.config.archive_path, name)
+        return path
 
     def get_named_results_for_run(self, *, name: str, run: str) -> list[list[Any]]:
+        if run is None:
+            return None
         path = os.path.join(self.csvpaths.config.archive_path, name)
         path = os.path.join(path, run)
+        return self._get_named_results_for_run(name=name, run=run, path=path)
+
+    #
+    # name = the named-paths / named-results name
+    # run = the path to run_dir minus the archive/name root
+    # path = the full path to the run_dir
+    #
+    def _get_named_results_for_run(
+        self, *, name: str, run: str, path: str
+    ) -> list[list[Any]]:
         instances = Nos(path).listdir()
-        rs = []
+        rs = [None for inst in instances if inst != "manifest.json"]
         for inst in instances:
             if inst == "manifest.json":
                 continue
             r = self.get_named_result_for_instance(
                 name=name, run_dir=path, run=run, instance=inst
             )
-            rs.append(r)
+            rs[r.index] = r
         return rs
 
     def get_named_result_for_instance(
         self, *, name: str, run_dir: str, run: str, instance: str
     ) -> list[list[Any]]:
-        instance_dir = os.path.join(run_dir, instance)
+        #
+        # run_dir is misnamed due to the reimplementation of resreffinder.
+        #
+        # pre-results ref finder 2 we handled the instances here, but
+        # with the new finder we handle names 3 and 4 in the finder where
+        # we should be handling everything. for now, the double check here
+        # to see if we need to add the instance to the path is fine, but
+        # it should be deleted.
+        #
+        _ = ""
+
+        if run_dir.endswith(f"/{instance}") or run_dir.endswith(f"\\{instance}"):
+            instance_dir = run_dir
+        else:
+            instance_dir = os.path.join(run_dir, instance)
         mani = ResultFileReader.manifest(instance_dir)
         #
         # csvpath needs to be loaded with all meta.json->metadata and some/most of runtime_data
@@ -572,9 +710,13 @@ class ResultsManager:  # pylint: disable=C0115
             csvpath.match = meta["runtime_data"]["match_part"]
             csvpath.delimiter = meta["runtime_data"]["delimiter"]
             csvpath.quotechar = meta["runtime_data"]["quotechar"]
+        vars = ResultFileReader.vars(instance_dir)
+        if vars:
+            csvpath.variables = vars
         #
         # this may not be complete. let's see if it works or needs more.
         #
+        # try:
         r = Result(
             csvpath=csvpath,
             paths_name=name,
@@ -584,5 +726,9 @@ class ResultsManager:  # pylint: disable=C0115
             run_time=dateutil.parser.parse(mani["time"]),
             runtime_data=meta["runtime_data"],
             by_line=not bool(mani["serial"]),
+            run_uuid=mani["run_uuid"],
         )
+        """
+        except Exception as e:
+        """
         return r
