@@ -18,7 +18,10 @@ from ..metadata import Metadata
 
 
 class ResultsRegistrar(Registrar, Listener):
+    """@private"""
+
     COMPLETE = "complete"
+    STARTED = "started"
 
     def __init__(
         self, *, csvpaths, run_dir: str, pathsname: str, results: list[Result] = None
@@ -32,11 +35,13 @@ class ResultsRegistrar(Registrar, Listener):
         self.type_name = "results"
 
     def register_start(self, mdata: ResultsMetadata) -> None:
-        mdata.status = "start"
+        mdata.status = ResultsRegistrar.STARTED
         mdata.manifest_path = self.manifest_path
         filename = mdata.named_file_name
         fingerprint = self.csvpaths.file_manager.get_fingerprint_for_name(filename)
         filepath = self.csvpaths.file_manager.get_named_file(filename)
+        if isinstance(filepath, list):
+            filepath = filepath[0]
         ffingerprint = self._fingerprint_file(filepath)
         mdata.named_file_fingerprint = ffingerprint
         if self.results and len(self.results) > 0:
@@ -91,6 +96,7 @@ class ResultsRegistrar(Registrar, Listener):
         m = {}
         m["time"] = mdata.time_string
         m["uuid"] = mdata.uuid_string
+        m["run_uuid"] = mdata.run_uuid_string
         m["serial"] = mdata.by_line is False
         if mdata.time_completed:
             m["time_completed"] = mdata.time_completed_string
@@ -101,8 +107,13 @@ class ResultsRegistrar(Registrar, Listener):
         m["status"] = mdata.status
         m["run_home"] = mdata.run_home
         m["named_results_name"] = mdata.named_results_name
+
+        #
         m["named_paths_name"] = mdata.named_paths_name
+        m["named_paths_uuid"] = mdata.named_paths_uuid
+        #
         m["named_file_name"] = mdata.named_file_name
+        m["named_file_uuid"] = mdata.named_file_uuid
         m["named_file_path"] = mdata.named_file_path
         m["named_file_size"] = mdata.named_file_size
         m["named_file_last_change"] = mdata.named_file_last_change
