@@ -38,6 +38,10 @@ class Arg:
     def is_noneable(self, n: bool) -> None:
         self._noneable = n
 
+    @property
+    def name(self) -> str:
+        return self._name
+
     @property
     def types(self) -> list[Type]:
         return self._types
@@ -209,7 +213,7 @@ class ArgSet:
             t = tuple(self._args[i].types)
             if not isinstance(s, t):
                 ii = i + 1
-                return f"arg {ii} is an unexpected type"
+                return f"arg {ii} is an unexpected type: {type(s)}"
         return None
 
     # ----------------------------
@@ -410,7 +414,7 @@ class Args:
         if not good:
             msg = None
             if self.matchable:
-                msg = f"Problem in {self.matchable.my_chain}: {_m}"
+                msg = f"Csvpath language problem in {self.matchable.my_chain}: {_m}"
             else:
                 msg = "CsvPath Language syntax problem"
             self._matchable.matcher.csvpath.error_manager.handle_error(
