@@ -8,6 +8,16 @@ class Yes(ValueProducer):
     """returns True"""
 
     def check_valid(self) -> None:
+        self.description = [
+            self._cap_name(),
+            self.wrap(
+                """\
+                    yes() always evaluates to True. It is similar to no() and none().
+            """
+            ),
+        ]
+
+        self.aliases = ["yes", "true"]
         self.args = Args(matchable=self)
         self.args.validate(self.siblings())
         super().check_valid()
