@@ -9,7 +9,7 @@ from ..args import Args
 
 
 class Every(ValueProducer):
-    """uses the % of values seen to select every N sightings of a
+    """selects every N sightings of a
     value. results in a list of counts of values (potentially
     quite expensive) behind the scenes for generating the %.
     since there isn't an intrinsic state we're exposing and the
@@ -17,10 +17,18 @@ class Every(ValueProducer):
     """
 
     def check_valid(self) -> None:
+        self.description = [
+            self.wrap(
+                """\
+                Matches every N times a value is seen.
+            """
+            ),
+        ]
+        self.name_qualifier = True
         self.args = Args(matchable=self)
         a = self.args.argset(2)
-        a.arg(types=[Matchable], actuals=[None, Any])
-        a.arg(types=[Term], actuals=[int])
+        a.arg(name="watch", types=[Matchable], actuals=[None, Any])
+        a.arg(name="pick every N", types=[Term], actuals=[int, float])
         self.args.validate(self.siblings())
         super().check_valid()
 
@@ -33,23 +41,20 @@ class Every(ValueProducer):
         cnt += 1
         self.matcher.set_variable(self.me(), tracking=tracked_value, value=cnt)
         #
-        # TODO: this conversion error should be caught by Args
+        # any conversion error will be caught by Args
         #
         every = child.right.to_value(skip=skip)
         i = ExpressionUtility.to_int(every)
-        if not isinstance(i, int):
-            msg = f"Cannot convert {every} to int"
-            self.matcher.csvpath.error_manager.handle_error(source=self, msg=msg)
-            if self.matcher.csvpath.do_i_raise():
-                raise MatchException(msg)
         self.value = cnt % i
 
     def _decide_match(self, skip=None) -> None:
         cnt = self.to_value(skip=skip)
-        if cnt == 0:
+        if self.nocontrib:
+            self.match = self.default_match()
+        elif cnt == 0:
             self.match = True
         else:
             self.match = False
 
     def me(self):
-        return self.qualifier if self.qualifier is not None else self.get_id(self)
+        return self.first_non_term_qualifier(self.get_id(self))
