@@ -8,6 +8,15 @@ class HasMatches(ValueProducer):
     """True if there have been matches."""
 
     def check_valid(self) -> None:  # pylint: disable=W0246
+        self.description = [
+            self._cap_name(),
+            self.wrap(
+                """\
+            True when the run has so far had one or more lines that matched. If a run
+            is collecting data, at least one line of data is collected.
+            """
+            ),
+        ]
         self.args = Args(matchable=self)
         self.args.validate(self.siblings())
         super().check_valid()  # pylint: disable=W0246
