@@ -7,6 +7,14 @@ class TotalLines(ValueProducer):
     """returns the total data lines count for the file (1-based"""
 
     def check_valid(self) -> None:
+        self.description = [
+            self._cap_name(),
+            self.wrap(
+                """\
+                    Returns the total data lines count for the file (1-based).
+            """
+            ),
+        ]
         self.args = Args(matchable=self)
         self.args.validate(self.siblings())
         super().check_valid()
