@@ -1,12 +1,12 @@
 # pylint: disable=C0114
-from ..function_focus import MatchDecider
+from ..function_focus import SideEffect
 from ..args import Args
 from csvpath.matching.productions.term import Term
 from csvpath.matching.productions.variable import Variable
 from csvpath.matching.functions.function import Function
 
 
-class Headers(MatchDecider):
+class Headers(SideEffect):
     """directs functions like any() to look in the headers.
     secondary purpose: do existence test for a header name or
     index for the current headers/whole file. header_name
@@ -14,9 +14,23 @@ class Headers(MatchDecider):
     """
 
     def check_valid(self) -> None:
+        self.description = [
+            self._cap_name(),
+            self.wrap(
+                """\
+                Directs certain functions, such as any(), to search in the headers. variables()
+                has the same function, but directing the search to the variables.
+
+                This function can also do an existance test, but that capability has been replaced by
+                header_name() and header_index().
+        """
+            ),
+        ]
         self.args = Args(matchable=self)
         self.args.argset(1).arg(
-            types=[None, Term, Variable, Function], actuals=[str, int]
+            name="depreciated arg",
+            types=[None, Term, Variable, Function],
+            actuals=[str, int],
         )
         self.args.validate(self.siblings())
         super().check_valid()
