@@ -12,6 +12,34 @@ class AboveBelow(MatchDecider):
     """this class implements greater-than, less-than"""
 
     def check_valid(self) -> None:
+        self.description = None
+        if self.name in ["gt", "above", "after"]:
+            self.aliases = ["gt", "above", "after"]
+            self.description = [
+                "Greater than",
+                f"{self.name}() returns true if a value is greater than another value.",
+            ]
+        elif self.name in ["lt", "below", "before"]:
+            self.aliases = ["lt", "below", "before"]
+            self.description = [
+                "Less than",
+                f"{self.name}() returns true if a value is less than another value.",
+            ]
+        elif self.name in ["gte", "ge"]:
+            self.aliases = ["gte", "ge"]
+            self.description = [
+                "Greater than or equal to",
+                f"{self.name}() returns true if a value is greater than or equal to another value.",
+            ]
+        elif self.name in ["lte", "le"]:
+            self.aliases = ["lte", "le"]
+            self.description = [
+                "Less than or equal to",
+                f"{self.name}() returns true if a value is less than or equal to another value.",
+            ]
+        #
+        #
+        #
         self.args = Args(matchable=self)
         a = self.args.argset(2)
         #
@@ -20,10 +48,12 @@ class AboveBelow(MatchDecider):
         # not Ok. we never expect that comparison.
         #
         a.arg(
+            name="relate this",
             types=[Term, Variable, Header, Function, Reference],
             actuals=[None, int, float, date, datetime, str],
         )
         a.arg(
+            name="to that",
             types=[Term, Variable, Header, Function, Reference],
             actuals=[None, int, float, date, datetime, str],
         )
@@ -69,6 +99,8 @@ class AboveBelow(MatchDecider):
 
     def _try_dates(self, a, b) -> bool:
         if ExpressionUtility.all([a, b], [datetime]):
+            a = ExpressionUtility.to_datetime(a)
+            b = ExpressionUtility.to_datetime(b)
             if self._above() and self.name != "gte":
                 return a.timestamp() > b.timestamp()
             elif self._above():
@@ -77,6 +109,8 @@ class AboveBelow(MatchDecider):
                 a.timestamp() < b.timestamp()
             return a.timestamp() <= b.timestamp()
         if ExpressionUtility.all([a, b], [date]):
+            a = ExpressionUtility.to_date(a)
+            b = ExpressionUtility.to_date(b)
             if self._above() and self.name != "gte":
                 return a > b
             elif self._above():
