@@ -10,10 +10,26 @@ class Divide(ValueProducer):
     """divides numbers"""
 
     def check_valid(self) -> None:
+        self.description = [
+            self._cap_name(),
+            self.wrap(
+                """\
+            Divides numbers. divide() can take any number of int and/or float arguments.
+            """
+            ),
+        ]
         self.args = Args(matchable=self)
         a = self.args.argset()
-        a.arg(types=[Term, Variable, Header, Function, Reference], actuals=[int])
-        a.arg(types=[Term, Variable, Header, Function, Reference], actuals=[int])
+        a.arg(
+            name="dividend",
+            types=[Term, Variable, Header, Function, Reference],
+            actuals=[int, float],
+        )
+        a.arg(
+            name="divisor",
+            types=[Term, Variable, Header, Function, Reference],
+            actuals=[int, float],
+        )
         self.args.validate(self.siblings())
         super().check_valid()
 
