@@ -11,9 +11,26 @@ class Int(ValueProducer):
     """attempts to convert a value to an int"""
 
     def check_valid(self) -> None:
+        self.description = [
+            self._cap_name(),
+            self.wrap(
+                """\
+                    Casts a value to an int.
+
+                    Note that the actuals in the data signatures are types that
+                    the value must convert to. A bool True would convert to 1 and
+                    would therefore be castable using this function.
+                """
+            ),
+        ]
+
         self.args = Args(matchable=self)
         a = self.args.argset(1)
-        a.arg(types=[Term, Variable, Header, Function], actuals=[None, int, float])
+        a.arg(
+            name="cast this",
+            types=[Term, Variable, Header, Function],
+            actuals=[None, int, float],
+        )
         self.args.validate(self.siblings())
         super().check_valid()
 
@@ -30,6 +47,7 @@ class Int(ValueProducer):
                     raise MatchException(msg)
 
     def _decide_match(self, skip=None) -> None:
+        self.to_value(skip=skip)
         self.match = self.default_match()  # pragma: no cover
 
 
@@ -56,4 +74,5 @@ class Float(ValueProducer):
                     raise MatchException(msg)
 
     def _decide_match(self, skip=None) -> None:
+        self.to_value(skip=skip)
         self.match = self.default_match()  # pragma: no cover
