@@ -1,6 +1,7 @@
 # pylint: disable=C0114
 from ..function_focus import ValueProducer
 from csvpath.matching.productions import Term, Variable, Header, Reference, Equality
+from csvpath.matching.util.expression_utility import ExpressionUtility
 from ..function import Function
 from ..args import Args
 
@@ -9,20 +10,35 @@ class Subtract(ValueProducer):
     """subtracts numbers"""
 
     def check_valid(self) -> None:
+        self.description = [
+            self._cap_name(),
+            f"{self.name}() subtracts two or more numbers.",
+            """ When there is only one argument, the number is flipped from positive
+                to negative or negative to positive.
+            """,
+        ]
+        self.aliases = ["subtract", "minus"]
         self.args = Args(matchable=self)
         a = self.args.argset()
-        a.arg(types=[Term, Header, Reference, Variable, Function], actuals=[int])
+        a.arg(
+            name="term",
+            types=[Term, Header, Reference, Variable, Function],
+            actuals=[int, float],
+        )
         self.args.validate(self.siblings())
         super().check_valid()
 
     def _produce_value(self, skip=None) -> None:
         child = self.children[0]
-        if isinstance(child, Term):
-            v = child.to_value()
-            v = int(v)
-            self.value = v * -1
-        elif isinstance(child, Equality):
+        if isinstance(child, Equality):
             self.value = self._do_sub(child, skip=skip)
+        else:
+            v = child.to_value()
+            #
+            # this will not fail. args already checked.
+            #
+            v = ExpressionUtility.to_float(v)
+            self.value = v * -1
 
     def _do_sub(self, child, skip=None):
         siblings = child.commas_to_list()
