@@ -8,9 +8,22 @@ class PercentUnique(ValueProducer):
     """return the % of a value that is unique over lines so far seen"""
 
     def check_valid(self) -> None:
+        self.description = [
+            self._cap_name(),
+            self.wrap(
+                """\
+                   Returns the percent of values of a header that are unique
+                   over the lines seen so far.
+
+                   Uses a percent_unique variable behind the scenes. Add a name
+                   qualifier to allow for more than one percent unique function.
+                """
+            ),
+        ]
+        self.name_qualifier = True
         self.args = Args(matchable=self)
         a = self.args.argset(1)
-        a.arg(types=[Header], actuals=[str])
+        a.arg(name="header to watch", types=[Header], actuals=[str])
         self.args.validate(self.siblings())
         super().check_valid()
 
@@ -25,13 +38,11 @@ class PercentUnique(ValueProducer):
         for v, k in enumerate(d):
             if d[k] == 1:
                 uniques += 1
-        t = self.matcher.csvpath.match_count
-        #
-        # no longer necessary. match is updated immediately
-        # that onmatch -- via line_matches() -- is True
-        #
-        # t += 1
-        self.value = round(uniques / t, 2) * 100
+        t = len(d)
+        if t == 0:
+            self.value = 0
+        else:
+            self.value = round(uniques / (t), 2) * 100
 
     def _decide_match(self, skip=None) -> None:
         v = self.to_value(skip=skip)
