@@ -6,12 +6,24 @@ from ..args import Args
 
 
 class Lower(ValueProducer):
-    """lowercases a string"""
+    """lower-cases a string"""
 
     def check_valid(self) -> None:
+        self.description = [
+            self._cap_name(),
+            self.wrap(
+                """\
+                   Alters a string by lower-casing it.
+                """
+            ),
+        ]
         self.args = Args(matchable=self)
         a = self.args.argset(1)
-        a.arg(types=[Term, Variable, Header, Function, Reference], actuals=[str])
+        a.arg(
+            name="lowercase this",
+            types=[Term, Variable, Header, Function, Reference],
+            actuals=[str],
+        )
         self.args.validate(self.siblings())
         super().check_valid()
 
