@@ -8,17 +8,20 @@ from .type import Type
 
 class Email(Type):
     def check_valid(self) -> None:
+        self.match_qualifiers.append("notnone")
+        self.value_qualifiers.append("notnone")
+        self.description = [
+            self._cap_name(),
+            "A line() schema type indicating that the value it represents must be an email",
+        ]
+        #
+        #
+        #
         self.args = Args(matchable=self)
         a = self.args.argset(1)
         a.arg(
-            name="header to validate",
-            types=[Header],
-            actuals=[str],
-        )
-        a = self.args.argset(1)
-        a.arg(
-            name="other possible sources to check",
-            types=[Variable, Reference, Function],
+            name="address",
+            types=[Header, Variable, Reference, Function],
             actuals=[str, None, self.args.EMPTY_STRING],
         )
         self.args.validate(self.siblings())
