@@ -5,17 +5,22 @@ from csvpath.matching.productions import Variable, Header, Reference, Term
 from csvpath.matching.functions.function import Function
 from ..args import Args
 from ..function_focus import ValueProducer
+from .type import Type
 
 
-class Nonef(ValueProducer):
+class Nonef(ValueProducer, Type):
     """returns None"""
 
     def check_valid(self) -> None:
+        self.description = [
+            self._cap_name(),
+            "A value producer and line() schema type representing a None value.",
+        ]
         self.args = Args(matchable=self)
         self.args.argset(0)
         a = self.args.argset(1)
         a.arg(
-            name="null check",
+            name="nullable",
             types=[Variable, Header, Function, Reference],
             actuals=[None],
         )
@@ -43,10 +48,16 @@ class Nonef(ValueProducer):
             self.match = ExpressionUtility.is_none(self._value_one(skip=skip))
 
 
-class Blank(ValueProducer):
+class Blank(ValueProducer, Type):
     """returns True to match, returns its child's value or None. represents any value"""
 
     def check_valid(self) -> None:
+        self.aliases = ["blank", "nonspecific", "unspecified"]
+        self.description = [
+            self._cap_name(),
+            "A line() schema type representing an incompletely specified header.",
+            "It can take a string naming its positional header.",
+        ]
         self.args = Args(matchable=self)
         self.args.argset(0)
         a = self.args.argset(1)
@@ -63,11 +74,16 @@ class Blank(ValueProducer):
         self.match = self.default_match()
 
 
-class Wildcard(ValueProducer):
+class Wildcard(ValueProducer, Type):
     """returns True to match, return value: the arg: 1-9+ or '*', or None.
     represents any number of headers"""
 
     def check_valid(self) -> None:
+        self.description = [
+            self._cap_name(),
+            f"A {self.name}() schema type represents one or more headers that are otherwise unspecified.",
+            "It may take an int indicating the number of headers or a * to indicate any number of headers.",
+        ]
         self.args = Args(matchable=self)
         a = self.args.argset(1)
         a.arg(types=[None, Term], actuals=[int, str])
