@@ -8,17 +8,17 @@ from .type import Type
 
 class Url(Type):
     def check_valid(self) -> None:
+        self.match_qualifiers.append("notnone")
+        self.value_qualifiers.append("notnone")
+        self.description = [
+            self._cap_name(),
+            "A line() schema type indicating that the value it represents must be an URL",
+        ]
         self.args = Args(matchable=self)
         a = self.args.argset(1)
         a.arg(
-            name="Url is mainly for validating headers",
-            types=[Header],
-            actuals=[str],
-        )
-        a = self.args.argset(1)
-        a.arg(
-            name="other value alternatives",
-            types=[Variable, Reference, Function],
+            name="url",
+            types=[Header, Variable, Reference, Function],
             actuals=[str, None, self.args.EMPTY_STRING],
         )
         self.args.validate(self.siblings())
