@@ -71,29 +71,53 @@ class Config:
 
     def __init__(self, *, load=True):
         self.load = load
-        self._cache_dir_path = None
-        self._function_imports = None
-        self._additional_listeners = None
-        self._csvpath_file_extensions = None
-        self._csv_file_extensions = None
-        self._csvpath_errors_policy = None
-        self._csvpaths_errors_policy = None
-        self._csvpath_log_level = None
-        self._csvpaths_log_level = None
-        self._log_file = None
-        self._log_files_to_keep = None
-        self._log_file_size = None
-        self._archive_path = None
-        self._transfer_root = None
-        self._inputs_files_path = None
-        self._inputs_csvpaths_path = None
         self._config = RawConfigParser()
         self.log_file_handler = None
-        self._configpath = environ.get(Config.CSVPATH_CONFIG_FILE_ENV)
+        self._configpath = None
+        #
+        # if env is set it is over anything else. However, the config.ini
+        # found by env var or any other way has its configpath evaluated and
+        # will be reloaded if it is found to be different. this could result
+        # an infinite loop, but that would be an unlikely user error easily
+        # corrected.
+        #
+        # pass in None to trigger a configpath load
+        self.configpath = None
+
+    @property
+    def configpath(self) -> str:
         if self._configpath is None:
-            self._configpath = Config.CONFIG
-        if self.load:
-            self._load_config()
+            self.configpath = None
+        return self._configpath
+
+    @configpath.setter
+    def configpath(self, path: str) -> None:
+        #
+        # if None passed in, check Env vars, if None, use default
+        #
+        if path is not None:
+            path = path.strip()
+        if path == "":
+            path = None
+        if path is None:
+            path = environ.get(Config.CSVPATH_CONFIG_FILE_ENV)
+            if path is not None:
+                path = path.strip()
+            if path == "":
+                path = None
+            if path is None:
+                path = Config.CONFIG
+        self._configpath = path
+        self._load_config()
+        # if newly loaded config path doesn't match where it was loaded from, reload w/it.
+        path = self.get(section="config", name="path")
+        if path is not None:
+            path = path.strip()
+        if path == "":
+            path = None
+        if path is not None and path != self._configpath:
+            # if recurse, could loop. but probably won't and not looping is user's responsibility.
+            self.configpath = path
 
     @property
     def load(self) -> bool:
@@ -109,32 +133,59 @@ class Config:
         self._load_config()
 
     def set_config_path_and_reload(self, path: str) -> None:
-        self._configpath = path
+        self.configpath = path
         self.reload()
 
     @property
     def config_path(self) -> str:
-        return self._configpath
+        return self.configpath
+
+    @property
+    def sections(self) -> list[str]:
+        return self._config.sections()
 
     def get(self, *, section: str, name: str, default=None):
         return self._get(section, name, default)
 
     def _get(self, section: str, name: str, default=None):
+        #
+        # TODO: we should swap all uppercase values for env var values if we find a
+        # matching env var. same as we do for metadata values
+        #
         if self._config is None:
             raise ConfigurationException("No config object available")
         try:
             s = self._config[section][name]
             ret = None
-            if s.find(",") > -1:
+            if s and isinstance(s, str) and s.find(",") > -1:
                 ret = [s.strip() for s in s.split(",")]
-            else:
+            elif isinstance(s, str):
                 ret = s.strip()
+            else:
+                ret = s
+
+            if ret and isinstance(ret, str) and ret.isupper():
+                v2 = os.getenv(ret)
+                if v2 is not None:
+                    ret = v2.strip()
             return ret
         except KeyError:
-            if self.csvpath_log_level == LogLevels.DEBUG:
-                print(f"Check config at {self.config_path} for [{section}][{name}]")
+            try:
+                if self._config["logging"]["csvpath"] == LogLevels.DEBUG:
+                    print(
+                        f"WARNING: Check config at {self.config_path} for [{section}][{name}]"
+                    )
+            except KeyError:
+                ...
             return default
 
+    def _set(self, section, key, value) -> None:
+        if isinstance(value, list):
+            value = ",".join(value)
+        if not self._config.has_section(section):
+            self._config.add_section(section)
+        self._config.set(section, key, value)
+
     #
     # adds the value to the internal configparser object. doesn't save.
     # does a refresh to make sure any lists or other interpreted values
@@ -149,36 +200,37 @@ class Config:
         #
         if value is None:
             value = ""
-        self._config[section][key] = value
+        #
+        # why would we not use _set(section, key, value)?
+        #
+        self._set(section, key, value)
         self.refresh()
 
     def save_config(self) -> None:
-        with open(self.configpath, "w") as f:
+        with open(self.configpath, "w", encoding="utf-8") as f:
             self._config.write(f)
 
     def _create_default_config(self) -> None:
         directory = ""
         name = ""
-        if self._configpath is None or self._configpath.strip() == "":
+        if self.configpath is None or self.configpath.strip() == "":
             raise ConfigurationException("Config path cannot be None")
-        if self._configpath.find(os.sep) > 0:
-            s = self._configpath.rfind(os.sep)
-            directory = self._configpath[0:s]
-            name = self._configpath[s + 1 :]
+        if self.configpath.find(os.sep) > 0:
+            s = self.configpath.rfind(os.sep)
+            directory = self.configpath[0:s]
+            name = self.configpath[s + 1 :]
         if directory != "":
             if not path.exists(directory):
                 os.makedirs(directory)
-        with open(self._configpath, "w", encoding="utf-8") as file:
+        with open(self.configpath, "w", encoding="utf-8") as file:
             c = f"""
-[csvpath_files]
-extensions = txt, csvpath, csvpaths
-
-[csv_files]
-extensions = txt, csv, tsv, dat, tab, psv, ssv
+[extensions]
+csvpath_files = csvpath, csvpaths
+csv_files = csv, tsv, dat, tab, psv, ssv
 
 [errors]
 csvpath = collect, fail, print
-csvpaths = raise, collect
+csvpaths = print, collect
 use_format = full
 pattern = {{time}}:{{file}}:{{line}}:{{paths}}:{{instance}}:{{chain}}:  {{message}}
 
@@ -187,7 +239,9 @@ csvpath = info
 csvpaths = info
 log_file = logs{os.sep}csvpath.log
 log_files_to_keep = 100
-log_file_size = 52428800
+log_file_size = 50000000
+# file or rotating
+handler = file
 
 [config]
 path =
@@ -198,10 +252,35 @@ imports =
 [cache]
 path =
 
+[results]
+archive = archive
+transfers = transfers
+
+[inputs]
+files = inputs{os.sep}named_files
+csvpaths = inputs{os.sep}named_paths
+on_unmatched_file_fingerprints = halt
+
 [listeners]
 # add listener group names to send events to the channel they represent
 groups = default
-#slack, marquez, ckan, sftp, sftpplus, otlp
+#slack, marquez, ckan, sftp, sftpplus, otlp, sqlite, sql
+
+# general purpose webhook caller
+webhook.results = from csvpath.managers.integrations.webhook.webhook_results_listener import WebhookResultsListener
+
+# add a listener to exec scripts at the end of named-paths group runs
+scripts.results = from csvpath.managers.integrations.scripts.scripts_results_listener import ScriptsResultsListener
+
+# add sql to capture results in mysql, postgres, ms sql server, or sqlite
+sql.file = from csvpath.managers.integrations.sql.sql_file_listener import SqlFileListener
+sql.paths = from csvpath.managers.integrations.sql.sql_paths_listener import SqlPathsListener
+sql.result = from csvpath.managers.integrations.sql.sql_result_listener import SqlResultListener
+sql.results = from csvpath.managers.integrations.sql.sql_results_listener import SqlResultsListener
+
+# add sqlite to capture results in a local sqlite file
+sqlite.results = from csvpath.managers.integrations.sqlite.sqlite_results_listener import SqliteResultsListener
+sqlite.result = from csvpath.managers.integrations.sqlite.sqlite_result_listener import SqliteResultListener
 
 # add to capture a history of all named-file stagings and all named-paths loads in
 # an [inputs] files and an[inputs] paths root manifest.json
@@ -214,7 +293,7 @@ otlp.results = from csvpath.managers.integrations.otlp.otlp_results_listener imp
 otlp.errors = from csvpath.managers.integrations.otlp.otlp_error_listener import OpenTelemetryErrorListener
 
 # add sftp to the list of groups above to push content and metadata to an SFTP account
-sftp.results = from csvpath.managers.integrations.sftp.sftp_listener import SftpListener
+sftp.results = from csvpath.managers.integrations.sftp.sftp_sender import SftpSender
 
 # add sftpplus to the list of groups above to automate registration and named-paths group runs on file arrival at an SFTPPlus server
 sftpplus.paths = from csvpath.managers.integrations.sftpplus.sftpplus_listener import SftpPlusListener
@@ -234,6 +313,20 @@ slack.paths = from csvpath.managers.integrations.slack.sender import SlackSender
 slack.result = from csvpath.managers.integrations.slack.sender import SlackSender
 slack.results = from csvpath.managers.integrations.slack.sender import SlackSender
 
+[sqlite]
+db = archive/csvpath.db
+
+[sql]
+# mysql, postgres, sql_server, or sqlite
+dialect = sqlite
+connection_string = sqlite:///archive/csvpath-sqlite.db
+
+[sftp]
+server = localhost
+port = 22
+username =
+password =
+
 [sftpplus]
 # these are only needed on the server
 admin_username = SFTPPLUS_ADMIN_USERNAME
@@ -248,7 +341,6 @@ mailbox_password = SFTPPLUS_MAILBOX_PASSWORD
 server = SFTPPLUS_SERVER
 port = SFTPPLUS_PORT
 
-
 [ckan]
 server = http://localhost:80
 api_token =
@@ -266,15 +358,25 @@ verify = False
 # on-invalid-slack: webhook-minus-'https://'
 webhook_url =
 
-[results]
-archive = archive
-transfers = transfers
-[inputs]
-files = inputs{os.sep}named_files
-csvpaths = inputs{os.sep}named_paths
-on_unmatched_file_fingerprints = halt
+[scripts]
+run_scripts = no
+shell = /bin/bash
+
+
             """
+
             file.write(c)
+            #
+            # writing a new config means we want to immediately load it?
+            # possibly not.
+            #
+            self._assure_logs_path()
+            self._assure_archive_path()
+            self._assure_transfer_root()
+            self._assure_inputs_files_path()
+            self._assure_cache_path()
+            self._assure_inputs_csvpaths_path()
+
             print(f"Created a default config file at {directory} with name {name}.")
             print("If you want your config to be somewhere else remember to")
             print("update the path in the default config.ini")
@@ -290,10 +392,8 @@ on_unmatched_file_fingerprints = halt
                 os.makedirs(dirpath)
 
     def _get_dir_path(self, filepath):
-        if filepath.find(os.sep) > -1:
-            dirpath = filepath[0 : filepath.rfind(os.sep)]
-            return dirpath
-        return None
+        p = os.path.dirname(filepath)
+        return p if not p == "" else None
 
     def _assure_archive_path(self) -> None:
         if self.load:
@@ -301,9 +401,43 @@ on_unmatched_file_fingerprints = halt
                 self.archive_path = "archive"
             if self.archive_path.strip().lower().startswith("s3://"):
                 return
+            if self.archive_path.strip().lower().startswith("azure://"):
+                return
+            if self.archive_path.strip().lower().startswith("sftp://"):
+                return
             if not path.exists(self.archive_path):
                 os.makedirs(self.archive_path)
 
+    @property
+    def archive_sep(self) -> None:
+        if self.archive_path is None or self.archive_path.strip() == "":
+            return os.sep
+        a = self.archive_path.strip().lower()
+        if a.find("://") > -1:
+            return "/"
+        return os.sep
+
+    @property
+    def files_sep(self) -> None:
+        if self.inputs_files_path is None or self.inputs_files_path.strip() == "":
+            return os.sep
+        a = self.inputs_files_path.strip().lower()
+        if a.find("://") > -1:
+            return "/"
+        return os.sep
+
+    @property
+    def csvpaths_sep(self) -> None:
+        if (
+            self._assure_inputs_csvpaths_path is None
+            or self._assure_inputs_csvpaths_path.strip() == ""
+        ):
+            return os.sep
+        a = self._assure_inputs_csvpaths_path.strip().lower()
+        if a.find("://") > -1:
+            return "/"
+        return os.sep
+
     def _assure_transfer_root(self) -> None:
         if self.load:
             if self.transfer_root is None or self.transfer_root.strip() == "":
@@ -317,6 +451,12 @@ on_unmatched_file_fingerprints = halt
                 self.inputs_files_path = f"inputs{os.sep}named_files"
             if self.inputs_files_path.strip().lower().startswith("s3://"):
                 return
+            if self.inputs_files_path.strip().lower().startswith("azure://"):
+                return
+            if self.inputs_files_path.strip().lower().startswith("sftp://"):
+                return
+            if self.inputs_files_path.strip().lower().startswith("gs://"):
+                return
             if not path.exists(self.inputs_files_path):
                 os.makedirs(self.inputs_files_path)
 
@@ -329,6 +469,12 @@ on_unmatched_file_fingerprints = halt
                 self.inputs_csvpaths_path = f"inputs{os.sep}named_paths"
             if self.inputs_csvpaths_path.strip().lower().startswith("s3://"):
                 return
+            if self.inputs_csvpaths_path.strip().lower().startswith("azure://"):
+                return
+            if self.inputs_csvpaths_path.strip().lower().startswith("sftp://"):
+                return
+            if self.inputs_csvpaths_path.strip().lower().startswith("gs://"):
+                return
             if not path.exists(self.inputs_csvpaths_path):
                 os.makedirs(self.inputs_csvpaths_path)
 
@@ -337,16 +483,24 @@ on_unmatched_file_fingerprints = halt
         if uc and uc.strip().lower() == "no":
             return
         if self.load:
-            if self.cache_dir_path is None or self.cache_dir_path.strip() == "":
-                self.cache_dir_path = "cache"
-            if not path.exists(self.cache_dir_path):
-                os.makedirs(self.cache_dir_path)
+            p = self._get("cache", "path", "cache")
+            if p:
+                p = p.strip()
+            if p == "":
+                self._set("cache", "use_cache", "no")
+                return
+            if p.find("://") > -1:
+                raise ConfigurationException(
+                    f"Cache dir must be on the local drive, not {p}"
+                )
+            if not os.path.exists(p):
+                os.makedirs(p)
 
     def _assure_config_file_path(self) -> None:
         if self.load:
-            if not self._configpath or self._configpath.strip() == "":
-                self._configpath = Config.CONFIG
-            if not os.path.isfile(self._configpath):
+            if not self.configpath or self.configpath.strip() == "":
+                self.configpath = Config.CONFIG
+            if not os.path.isfile(self.configpath):
                 self._create_default_config()
 
     def _load_config(self, norecurse=False):
@@ -356,10 +510,7 @@ on_unmatched_file_fingerprints = halt
             )
             return
         self._assure_config_file_path()
-        #
-        #
-        #
-        self._config.read(self._configpath)
+        self._config.read(self.configpath)
         self.refresh()
 
     #
@@ -368,70 +519,41 @@ on_unmatched_file_fingerprints = halt
     # file, it just gathers and translates settings for external use.
     #
     def refresh(self) -> None:
-        self.csvpath_file_extensions = self._get(
-            Sections.CSVPATH_FILES.value, "extensions"
-        )
-        self.csv_file_extensions = self._get(Sections.CSV_FILES.value, "extensions")
-
-        self.csvpath_errors_policy = self._get(Sections.ERRORS.value, "csvpath")
-        self.csvpaths_errors_policy = self._get(Sections.ERRORS.value, "csvpaths")
-
+        #
+        # the sections: csv_files and csvpath_files are deprecated in favor of
+        # a single extensions section with csv_files and csvpath_files as keys.
+        # is is a simpler way to go and will UI better. the old way can hang about
+        # for a release or two, but should be retired soon.
+        #
+        #
+        # file extensions will reload themselves as long as we clear them
+        #
+        self.csvpath_file_extensions = None
+        self.csv_file_extensions = None
+        #
+        #
+        #
         self.csvpath_log_level = self._get(Sections.LOGGING.value, "csvpath")
         self.csvpaths_log_level = self._get(Sections.LOGGING.value, "csvpaths")
 
         self.log_file = self._get(Sections.LOGGING.value, LogFile.LOG_FILE.value)
         self.log_files_to_keep = self._get(
-            Sections.LOGGING.value, LogFile.LOG_FILES_TO_KEEP.value
+            Sections.LOGGING.value, LogFile.LOG_FILES_TO_KEEP.value, 10
         )
         self.log_file_size = self._get(
-            Sections.LOGGING.value, LogFile.LOG_FILE_SIZE.value
+            Sections.LOGGING.value, LogFile.LOG_FILE_SIZE.value, 12800000
         )
-        # path to external functions list. external functions are very optional.
-        # not blowing up when absent seems reasonable.
-        try:
-            self.function_imports = self._get(Sections.FUNCTIONS.value, "imports")
-        except Exception:
-            print(
-                "WARNING: config cannot load [functions][imports] from {self.configpath}"
-            )
-            pass
-        # likewise caching.
-        try:
-            self.cache_dir_path = self._get(Sections.CACHE.value, "path")
-        except Exception:
-            print("WARNING: config cannot load [cache][path] from {self.configpath}")
-            pass
-        #
-        # reload if another config path is set
-        #
         path = self._get("config", "path")
         if path:
             path = path.strip().lower()
-        if path and path != "" and path != self._configpath.strip().lower():
-            self._configpath = path
+        if path and path != "" and path != self.configpath.strip().lower():
+            self.configpath = path
             self.reload()
             return
         self.validate_config()
 
     def validate_config(self) -> None:
         #
-        # files
-        #
-        if (
-            self.csvpath_file_extensions is None
-            or not isinstance(self.csvpath_file_extensions, list)
-            or not len(self.csvpath_file_extensions) > 0
-        ):
-            raise ConfigurationException(
-                f"CsvPath file extensions are wrong: {self.csvpath_file_extensions}"
-            )
-        if (
-            self.csv_file_extensions is None
-            or not isinstance(self.csv_file_extensions, list)
-            or not len(self.csv_file_extensions) > 0
-        ):
-            raise ConfigurationException("CSV file extensions are wrong")
-        #
         # error policies
         #
         if (
@@ -439,7 +561,9 @@ on_unmatched_file_fingerprints = halt
             or not isinstance(self.csvpath_errors_policy, list)
             or not len(self.csvpath_errors_policy) > 0
         ):
-            raise ConfigurationException("CsvPath error policy is wrong")
+            raise ConfigurationException(
+                f"CsvPath error policy is wrong: {self.csvpath_errors_policy}"
+            )
         for _ in self.csvpath_errors_policy:
             if _ not in [s.value for s in OnError]:
                 raise ConfigurationException(f"CsvPath error policy {_} is wrong")
@@ -499,14 +623,6 @@ on_unmatched_file_fingerprints = halt
 
     # ======================================
 
-    @property
-    def configpath(self) -> str:
-        return self._configpath
-
-    @configpath.setter
-    def configpath(self, path: str) -> None:
-        self._configpath = path
-
     def additional_listeners(self, listener_type) -> list[str]:
         # pull type for group names
         # for each group name find:
@@ -526,11 +642,11 @@ on_unmatched_file_fingerprints = halt
 
     @property
     def cache_dir_path(self) -> str:
-        return self._cache_dir_path
+        return self._get("cache", "path")
 
     @cache_dir_path.setter
     def cache_dir_path(self, p) -> None:
-        self._cache_dir_path = p
+        self._set("cache", "path", p)
 
     def halt_on_unmatched_file_fingerprints(self) -> bool:
         houf = self._get("inputs", "on_unmatched_file_fingerprints")
@@ -542,153 +658,194 @@ on_unmatched_file_fingerprints = halt
 
     @property
     def transfer_root(self) -> str:
-        if self._transfer_root is None:
-            self._transfer_root = self._get("results", "transfers")
-            if self._transfer_root is None:
-                self._transfer_root = "transfers"
-                self.add_to_config("results", "transfers", "transfers")
-        return self._transfer_root
+        return self._get("results", "transfers", "transfers")
 
     @transfer_root.setter
     def transfer_root(self, p) -> None:
-        self._transfer_root = p
+        self._set("results", "transfers", p)
 
     @property
     def archive_path(self) -> str:
-        if self._archive_path is None:
-            self._archive_path = self._get("results", "archive")
-            if self._archive_path is None:
-                self._archive_path = "archive"
-                self.add_to_config("results", "archive", "archive")
-        return self._archive_path
+        return self._get("results", "archive", "archive")
 
     @archive_path.setter
     def archive_path(self, p) -> None:
-        self._archive_path = p
+        self._set("results", "archive", p)
 
     @property
     def archive_name(self) -> str:
         p = self.archive_path
-        if p.find(os.sep) > -1:
+        if p.find(self.archive_sep) > -1:
+            # if p.find(os.sep) > -1:
             p = p[p.rfind(os.sep) + 1 :]
         return p
 
     @property
     def inputs_files_path(self) -> str:
-        if self._inputs_files_path is None:
-            self._inputs_files_path = self._get("inputs", "files")
-            if self._inputs_files_path is None:
-                self._inputs_files_path = "inputs"
-                self.add_to_config("inputs", "files", f"inputs{os.sep}named_files")
-        return self._inputs_files_path
+        return self._get("inputs", "files", f"inputs{os.sep}named_files")
 
     @inputs_files_path.setter
     def inputs_files_path(self, p) -> None:
-        self._inputs_files_path = p
+        self._set("inputs", "files", p)
 
     @property
     def inputs_csvpaths_path(self) -> str:
-        if self._inputs_csvpaths_path is None:
-            self._inputs_csvpaths_path = self._get("inputs", "csvpaths")
-            if self._inputs_csvpaths_path is None:
-                self._inputs_csvpaths_path = "inputs"
-                self.add_to_config("inputs", "csvpaths", f"inputs{os.sep}named_paths")
-        return self._inputs_csvpaths_path
+        return self._get("inputs", "csvpaths", f"inputs{os.sep}named_paths")
 
     @inputs_csvpaths_path.setter
     def inputs_csvpaths_path(self, p) -> None:
-        self._inputs_csvpaths_path = p
+        self._set("inputs", "csvpaths", p)
 
     @property
     def function_imports(self) -> str:
-        return self._function_imports
+        return self._get(Sections.FUNCTIONS.value, "imports", "imports")
 
     @function_imports.setter
     def function_imports(self, path: str) -> None:
-        self._function_imports = path
+        self._set(Sections.FUNCTIONS.value, "imports", path)
 
     @property
     def csvpath_file_extensions(self) -> list[str]:
-        return self._csvpath_file_extensions
+        # if self._csvpath_file_extensions is None:
+        cs = self._get("extensions", "csvpath_files")
+        if not cs or len(cs) == 0:
+            #
+            # the old way
+            #
+            cs = self._get(Sections.CSVPATH_FILES.value, "extensions")
+            if not cs or len(cs) == 0:
+                cs = ["csvpath", "csvpaths"]
+        return cs
+        #    self._csvpath_file_extensions = cs
+        # return self._csvpath_file_extensions
 
     @csvpath_file_extensions.setter
     def csvpath_file_extensions(self, ss: list[str]) -> None:
         if isinstance(ss, str):
             ss = [ss]
-        self._csvpath_file_extensions = ss
+        self._set("extensions", "csvpath_files", ss)
+        # self._csvpath_file_extensions = ss
 
     @property
     def csv_file_extensions(self) -> list[str]:
-        return self._csv_file_extensions
+        # if self._csv_file_extensions is None:
+        cs = self._get("extensions", Sections.CSV_FILES.value)
+        if not cs or len(cs) == 0:
+            #
+            # the old way
+            #
+            cs = self._get(Sections.CSV_FILES.value, "extensions")
+            if not cs or len(cs) == 0:
+                cs = ["csv", "xlsx"]
+        return cs
+        #    self._csv_file_extensions = cs
+        # return self._csv_file_extensions
 
     @csv_file_extensions.setter
     def csv_file_extensions(self, ss: list[str]) -> None:
         if isinstance(ss, str):
             ss = [ss]
-        self._csv_file_extensions = ss
+        self._set("extensions", Sections.CSVPATH_FILES.value, ss)
+        # self._csv_file_extensions = ss
 
     @property
     def csvpath_errors_policy(self) -> list[str]:
-        return self._csvpath_errors_policy
+        p = self._get(
+            Sections.ERRORS.value,
+            "csvpath",
+            ["print", "stop", "fail", "collect"],
+        )
+        if not isinstance(p, list):
+            return [p]
+        return p
+        # return self._csvpath_errors_policy
 
     @csvpath_errors_policy.setter
     def csvpath_errors_policy(self, ss: list[str]) -> None:
         if isinstance(ss, str):
             ss = [ss]
-        self._csvpath_errors_policy = ss
+        self._set(Sections.ERRORS.value, "csvpath", ss)
+        # self._csvpath_errors_policy = ss
 
     @property
     def csvpaths_errors_policy(self) -> list[str]:
-        return self._csvpaths_errors_policy
+        p = self._get(
+            Sections.ERRORS.value,
+            "csvpaths",
+            ["print", "stop", "fail", "collect"],
+        )
+        if isinstance(p, str):
+            return [p]
+        return p
+        # return self._csvpaths_errors_policy
 
     @csvpaths_errors_policy.setter
     def csvpaths_errors_policy(self, ss: list[str]) -> None:
         if isinstance(ss, str):
             ss = [ss]
-        self._csvpaths_errors_policy = ss
+        self._set(Sections.ERRORS.value, "csvpaths", ss)
+        # self._csvpaths_errors_policy = ss
 
     @property
     def csvpath_log_level(self) -> str:
-        return self._csvpath_log_level
+        return self._get("logging", "csvpath")
+        # return self._csvpath_log_level
 
     @csvpath_log_level.setter
     def csvpath_log_level(self, s: str) -> None:
-        self._csvpath_log_level = s
+        self._set("logging", "csvpath", s)
+        # self._csvpath_log_level = s
 
     @property
     def csvpaths_log_level(self) -> str:
-        return self._csvpaths_log_level
+        return self._get("logging", "csvpaths")
+        # return self._csvpaths_log_level
 
     @csvpaths_log_level.setter
     def csvpaths_log_level(self, s: str) -> None:
-        self._csvpaths_log_level = s
+        self._set("logging", "csvpaths", s)
+        # self._csvpaths_log_level = s
 
     @property
     def log_file(self) -> str:
-        return self._log_file
+        return self.get(section="logging", name="log_file")
+        # return self._log_file
 
     @log_file.setter
     def log_file(self, s: str) -> None:
-        self._log_file = s
+        self._set("logging", "log_file", s)
+        # self._log_file = s
 
     @property
     def log_files_to_keep(self) -> int:
-        return self._log_files_to_keep
+        fs = self._get(Sections.LOGGING.value, LogFile.LOG_FILES_TO_KEEP.value, 10)
+        try:
+            fs = int(fs)
+        except ValueError:
+            return 10
+        return fs
 
     @log_files_to_keep.setter
     def log_files_to_keep(self, i: int) -> None:
         try:
-            self._log_files_to_keep = int(i)
-        except (TypeError, ValueError):
-            raise ConfigurationException("Error in log_files_to_keep config")
+            i = int(i)
+        except (ValueError, TypeError):
+            i = 10
+        self._set(Sections.LOGGING.value, LogFile.LOG_FILES_TO_KEEP.value, i)
 
     @property
     def log_file_size(self) -> int:
-        return self._log_file_size
+        fs = self._get(Sections.LOGGING.value, LogFile.LOG_FILE_SIZE.value, 12800000)
+        try:
+            fs = int(fs)
+        except ValueError:
+            fs = 12800000
+        return fs
 
     @log_file_size.setter
     def log_file_size(self, i: int) -> None:
         try:
-            self._log_file_size = int(i)
+            i = int(i)
         except (TypeError, ValueError):
-            raise ConfigurationException("Error in log_files_size config")
+            i = 12800000
+        self._set(Sections.LOGGING.value, LogFile.LOG_FILE_SIZE.value, i)
