@@ -21,19 +21,20 @@ class S3XlsxDataReader(XlsxDataReader):
 
     def load_if(self) -> None:
         if self.source is None:
-            client = Box.STUFF.get("boto_s3_client")
+            client = Box().get("boto_s3_client")
             if client is None:
                 client = S3Utils.make_client()
             try:
-                self.source = open(
-                    self._path, "rb", transport_params={"client": client}
-                )
+                #
+                # binary files, always rb
+                #
+                self.source = open(self.path, "rb", transport_params={"client": client})
             except DeprecationWarning:
                 ...
 
     def fingerprint(self) -> str:
         self.load_if()
-        h = S3Fingerprinter().fingerprint(self._path)
+        h = S3Fingerprinter().fingerprint(self.path)
         h = Hasher.percent_encode(h)
         self.close()
         return h
